<?php

if(!function_exists('aoki_qodef_design_styles')) {
    /**
     * Generates general custom styles
     */
    function aoki_qodef_design_styles() {
	    $font_family = aoki_qodef_options()->getOptionValue( 'google_fonts' );
	    if ( ! empty( $font_family ) && aoki_qodef_is_font_option_valid( $font_family ) ) {
		    $font_family_selector = array(
			    'body'
		    );
		    echo aoki_qodef_dynamic_css( $font_family_selector, array( 'font-family' => aoki_qodef_get_font_option_val( $font_family ) ) );
	    }
	
	    $page_background_color = aoki_qodef_options()->getOptionValue( 'page_background_color' );
	    if ( ! empty( $page_background_color ) ) {
		    $background_color_selector = array(
			    'body',
			    '.qodef-content',
			    '.qodef-container'
		    );
		    echo aoki_qodef_dynamic_css( $background_color_selector, array( 'background-color' => $page_background_color ) );
	    }
	
	    $selection_color = aoki_qodef_options()->getOptionValue( 'selection_color' );
	    if ( ! empty( $selection_color ) ) {
		    echo aoki_qodef_dynamic_css( '::selection', array( 'background' => $selection_color ) );
		    echo aoki_qodef_dynamic_css( '::-moz-selection', array( 'background' => $selection_color ) );
	    }
	
	    $preload_background_styles = array();
	
	    if ( aoki_qodef_options()->getOptionValue( 'preload_pattern_image' ) !== "" ) {
		    $preload_background_styles['background-image'] = 'url(' . aoki_qodef_options()->getOptionValue( 'preload_pattern_image' ) . ') !important';
	    }
	
	    echo aoki_qodef_dynamic_css( '.qodef-preload-background', $preload_background_styles );
    }

    add_action('aoki_qodef_style_dynamic', 'aoki_qodef_design_styles');
}

if ( ! function_exists( 'aoki_qodef_content_styles' ) ) {
	function aoki_qodef_content_styles() {
		$content_style = array();
		
		$padding_top = aoki_qodef_options()->getOptionValue( 'content_top_padding' );
		if ( $padding_top !== '' ) {
			$content_style['padding-top'] = aoki_qodef_filter_px( $padding_top ) . 'px';
		}
		
		$content_selector = array(
			'.qodef-content .qodef-content-inner > .qodef-full-width > .qodef-full-width-inner',
		);
		
		echo aoki_qodef_dynamic_css( $content_selector, $content_style );
		
		$content_style_in_grid = array();
		
		$padding_top_in_grid = aoki_qodef_options()->getOptionValue( 'content_top_padding_in_grid' );
		if ( $padding_top_in_grid !== '' ) {
			$content_style_in_grid['padding-top'] = aoki_qodef_filter_px( $padding_top_in_grid ) . 'px';
		}
		
		$content_selector_in_grid = array(
			'.qodef-content .qodef-content-inner > .qodef-container > .qodef-container-inner',
		);
		
		echo aoki_qodef_dynamic_css( $content_selector_in_grid, $content_style_in_grid );
	}
	
	add_action( 'aoki_qodef_style_dynamic', 'aoki_qodef_content_styles' );
}

if ( ! function_exists( 'aoki_qodef_h1_styles' ) ) {
	function aoki_qodef_h1_styles() {
		$margin_top    = aoki_qodef_options()->getOptionValue( 'h1_margin_top' );
		$margin_bottom = aoki_qodef_options()->getOptionValue( 'h1_margin_bottom' );
		
		$item_styles = aoki_qodef_get_typography_styles( 'h1' );
		
		if ( $margin_top !== '' ) {
			$item_styles['margin-top'] = aoki_qodef_filter_px( $margin_top ) . 'px';
		}
		if ( $margin_bottom !== '' ) {
			$item_styles['margin-bottom'] = aoki_qodef_filter_px( $margin_bottom ) . 'px';
		}
		
		$item_selector = array(
			'h1'
		);
		
		if ( ! empty( $item_styles ) ) {
			echo aoki_qodef_dynamic_css( $item_selector, $item_styles );
		}
	}
	
	add_action( 'aoki_qodef_style_dynamic', 'aoki_qodef_h1_styles' );
}

if ( ! function_exists( 'aoki_qodef_h2_styles' ) ) {
	function aoki_qodef_h2_styles() {
		$margin_top    = aoki_qodef_options()->getOptionValue( 'h2_margin_top' );
		$margin_bottom = aoki_qodef_options()->getOptionValue( 'h2_margin_bottom' );
		
		$item_styles = aoki_qodef_get_typography_styles( 'h2' );
		
		if ( $margin_top !== '' ) {
			$item_styles['margin-top'] = aoki_qodef_filter_px( $margin_top ) . 'px';
		}
		if ( $margin_bottom !== '' ) {
			$item_styles['margin-bottom'] = aoki_qodef_filter_px( $margin_bottom ) . 'px';
		}
		
		$item_selector = array(
			'h2'
		);
		
		if ( ! empty( $item_styles ) ) {
			echo aoki_qodef_dynamic_css( $item_selector, $item_styles );
		}
	}
	
	add_action( 'aoki_qodef_style_dynamic', 'aoki_qodef_h2_styles' );
}

if ( ! function_exists( 'aoki_qodef_h3_styles' ) ) {
	function aoki_qodef_h3_styles() {
		$margin_top    = aoki_qodef_options()->getOptionValue( 'h3_margin_top' );
		$margin_bottom = aoki_qodef_options()->getOptionValue( 'h3_margin_bottom' );
		
		$item_styles = aoki_qodef_get_typography_styles( 'h3' );
		
		if ( $margin_top !== '' ) {
			$item_styles['margin-top'] = aoki_qodef_filter_px( $margin_top ) . 'px';
		}
		if ( $margin_bottom !== '' ) {
			$item_styles['margin-bottom'] = aoki_qodef_filter_px( $margin_bottom ) . 'px';
		}
		
		$item_selector = array(
			'h3'
		);
		
		if ( ! empty( $item_styles ) ) {
			echo aoki_qodef_dynamic_css( $item_selector, $item_styles );
		}
	}
	
	add_action( 'aoki_qodef_style_dynamic', 'aoki_qodef_h3_styles' );
}

if ( ! function_exists( 'aoki_qodef_h4_styles' ) ) {
	function aoki_qodef_h4_styles() {
		$margin_top    = aoki_qodef_options()->getOptionValue( 'h4_margin_top' );
		$margin_bottom = aoki_qodef_options()->getOptionValue( 'h4_margin_bottom' );
		
		$item_styles = aoki_qodef_get_typography_styles( 'h4' );
		
		if ( $margin_top !== '' ) {
			$item_styles['margin-top'] = aoki_qodef_filter_px( $margin_top ) . 'px';
		}
		if ( $margin_bottom !== '' ) {
			$item_styles['margin-bottom'] = aoki_qodef_filter_px( $margin_bottom ) . 'px';
		}
		
		$item_selector = array(
			'h4'
		);
		
		if ( ! empty( $item_styles ) ) {
			echo aoki_qodef_dynamic_css( $item_selector, $item_styles );
		}
	}
	
	add_action( 'aoki_qodef_style_dynamic', 'aoki_qodef_h4_styles' );
}

if ( ! function_exists( 'aoki_qodef_h5_styles' ) ) {
	function aoki_qodef_h5_styles() {
		$margin_top    = aoki_qodef_options()->getOptionValue( 'h5_margin_top' );
		$margin_bottom = aoki_qodef_options()->getOptionValue( 'h5_margin_bottom' );
		
		$item_styles = aoki_qodef_get_typography_styles( 'h5' );
		
		if ( $margin_top !== '' ) {
			$item_styles['margin-top'] = aoki_qodef_filter_px( $margin_top ) . 'px';
		}
		if ( $margin_bottom !== '' ) {
			$item_styles['margin-bottom'] = aoki_qodef_filter_px( $margin_bottom ) . 'px';
		}
		
		$item_selector = array(
			'h5'
		);
		
		if ( ! empty( $item_styles ) ) {
			echo aoki_qodef_dynamic_css( $item_selector, $item_styles );
		}
	}
	
	add_action( 'aoki_qodef_style_dynamic', 'aoki_qodef_h5_styles' );
}

if ( ! function_exists( 'aoki_qodef_h6_styles' ) ) {
	function aoki_qodef_h6_styles() {
		$margin_top    = aoki_qodef_options()->getOptionValue( 'h6_margin_top' );
		$margin_bottom = aoki_qodef_options()->getOptionValue( 'h6_margin_bottom' );
		
		$item_styles = aoki_qodef_get_typography_styles( 'h6' );
		
		if ( $margin_top !== '' ) {
			$item_styles['margin-top'] = aoki_qodef_filter_px( $margin_top ) . 'px';
		}
		if ( $margin_bottom !== '' ) {
			$item_styles['margin-bottom'] = aoki_qodef_filter_px( $margin_bottom ) . 'px';
		}
		
		$item_selector = array(
			'h6'
		);
		
		if ( ! empty( $item_styles ) ) {
			echo aoki_qodef_dynamic_css( $item_selector, $item_styles );
		}
	}
	
	add_action( 'aoki_qodef_style_dynamic', 'aoki_qodef_h6_styles' );
}

if ( ! function_exists( 'aoki_qodef_text_styles' ) ) {
	function aoki_qodef_text_styles() {
		$item_styles = aoki_qodef_get_typography_styles( 'text' );
		
		$item_selector = array(
			'p'
		);
		
		if ( ! empty( $item_styles ) ) {
			echo aoki_qodef_dynamic_css( $item_selector, $item_styles );
		}
	}
	
	add_action( 'aoki_qodef_style_dynamic', 'aoki_qodef_text_styles' );
}

if ( ! function_exists( 'aoki_qodef_link_styles' ) ) {
	function aoki_qodef_link_styles() {
		$link_styles      = array();
		$link_color       = aoki_qodef_options()->getOptionValue( 'link_color' );
		$link_font_style  = aoki_qodef_options()->getOptionValue( 'link_fontstyle' );
		$link_font_weight = aoki_qodef_options()->getOptionValue( 'link_fontweight' );
		$link_decoration  = aoki_qodef_options()->getOptionValue( 'link_fontdecoration' );
		
		if ( ! empty( $link_color ) ) {
			$link_styles['color'] = $link_color;
		}
		if ( ! empty( $link_font_style ) ) {
			$link_styles['font-style'] = $link_font_style;
		}
		if ( ! empty( $link_font_weight ) ) {
			$link_styles['font-weight'] = $link_font_weight;
		}
		if ( ! empty( $link_decoration ) ) {
			$link_styles['text-decoration'] = $link_decoration;
		}
		
		$link_selector = array(
			'a',
			'p a'
		);
		
		if ( ! empty( $link_styles ) ) {
			echo aoki_qodef_dynamic_css( $link_selector, $link_styles );
		}
	}
	
	add_action( 'aoki_qodef_style_dynamic', 'aoki_qodef_link_styles' );
}

if ( ! function_exists( 'aoki_qodef_link_hover_styles' ) ) {
	function aoki_qodef_link_hover_styles() {
		$link_hover_styles     = array();
		$link_hover_color      = aoki_qodef_options()->getOptionValue( 'link_hovercolor' );
		$link_hover_decoration = aoki_qodef_options()->getOptionValue( 'link_hover_fontdecoration' );
		
		if ( ! empty( $link_hover_color ) ) {
			$link_hover_styles['color'] = $link_hover_color;
		}
		if ( ! empty( $link_hover_decoration ) ) {
			$link_hover_styles['text-decoration'] = $link_hover_decoration;
		}
		
		$link_hover_selector = array(
			'a:hover',
			'p a:hover'
		);
		
		if ( ! empty( $link_hover_styles ) ) {
			echo aoki_qodef_dynamic_css( $link_hover_selector, $link_hover_styles );
		}
		
		$link_heading_hover_styles = array();
		
		if ( ! empty( $link_hover_color ) ) {
			$link_heading_hover_styles['color'] = $link_hover_color;
		}
		
		$link_heading_hover_selector = array(
			'h1 a:hover',
			'h2 a:hover',
			'h3 a:hover',
			'h4 a:hover',
			'h5 a:hover',
			'h6 a:hover'
		);
		
		if ( ! empty( $link_heading_hover_styles ) ) {
			echo aoki_qodef_dynamic_css( $link_heading_hover_selector, $link_heading_hover_styles );
		}
	}
	
	add_action( 'aoki_qodef_style_dynamic', 'aoki_qodef_link_hover_styles' );
}

if ( ! function_exists( 'aoki_qodef_smooth_page_transition_styles' ) ) {
	function aoki_qodef_smooth_page_transition_styles( $style ) {
		$id            = aoki_qodef_get_page_id();
		$loader_style  = array();
		$current_style = '';
		
		$background_color = aoki_qodef_get_meta_field_intersect( 'smooth_pt_bgnd_color', $id );
		if ( ! empty( $background_color ) ) {
			$loader_style['background-color'] = $background_color;
		}
		
		$loader_selector = array(
			'.qodef-smooth-transition-loader',
			'.qodef-progress-loader div.qodef-char-mask > div'
		);
		
		if ( ! empty( $loader_style ) ) {
			$current_style .= aoki_qodef_dynamic_css( $loader_selector, $loader_style );
		}
		
		$spinner_style = array();
		$spinner_color = aoki_qodef_get_meta_field_intersect( 'smooth_pt_spinner_color', $id );
		if ( ! empty( $spinner_color ) ) {
			$spinner_style['background-color'] = $spinner_color;
			$spinner_style['color'] = $spinner_color;
		}
		
		$spinner_selectors = array(
			'.qodef-st-loader .qodef-rotate-circles > div',
			'.qodef-st-loader .pulse',
			'.qodef-st-loader .qodef-double-bounce .qodef-double-bounce1',
			'.qodef-st-loader .cube',
			'.qodef-st-loader .rotating_cubes .cube1',
			'.qodef-st-loader .rotating_cubes .cube2',
			'.qodef-st-loader .stripes > div',
			'.qodef-st-loader .wave > div',
			'.qodef-st-loader .two_rotating_circles .dot1',
			'.qodef-st-loader .two_rotating_circles .dot2',
			'.qodef-st-loader .five_rotating_circles .container1 > div',
			'.qodef-st-loader .five_rotating_circles .container2 > div',
			'.qodef-st-loader .five_rotating_circles .container3 > div',
			'.qodef-st-loader .atom .ball-1:before',
			'.qodef-st-loader .atom .ball-2:before',
			'.qodef-st-loader .atom .ball-3:before',
			'.qodef-st-loader .atom .ball-4:before',
			'.qodef-st-loader .clock .ball:before',
			'.qodef-st-loader .mitosis .ball',
			'.qodef-st-loader .lines .line1',
			'.qodef-st-loader .lines .line2',
			'.qodef-st-loader .lines .line3',
			'.qodef-st-loader .lines .line4',
			'.qodef-st-loader .fussion .ball',
			'.qodef-st-loader .fussion .ball-1',
			'.qodef-st-loader .fussion .ball-2',
			'.qodef-st-loader .fussion .ball-3',
			'.qodef-st-loader .fussion .ball-4',
			'.qodef-st-loader .wave_circles .ball',
			'.qodef-st-loader .pulse_circles .ball',
			'.qodef-progress-loader',
		);
		
		if ( ! empty( $spinner_style ) ) {
			$current_style .= aoki_qodef_dynamic_css( $spinner_selectors, $spinner_style );
		}
		
		$current_style = $current_style . $style;
		
		return $current_style;
	}
	
	add_filter( 'aoki_qodef_add_page_custom_style', 'aoki_qodef_smooth_page_transition_styles' );
}