<?php

if ( ! function_exists( 'aoki_qodef_get_blog_list_types_options' ) ) {
	function aoki_qodef_get_blog_list_types_options() {
		$blog_list_type_options = apply_filters( 'aoki_qodef_blog_list_type_global_option', $blog_list_type_options = array() );
		
		return $blog_list_type_options;
	}
}

if ( ! function_exists( 'aoki_qodef_blog_options_map' ) ) {
	function aoki_qodef_blog_options_map() {
		$blog_list_type_options = aoki_qodef_get_blog_list_types_options();
		
		aoki_qodef_add_admin_page(
			array(
				'slug'  => '_blog_page',
				'title' => esc_html__( 'Blog', 'aoki' ),
				'icon'  => 'fa fa-files-o'
			)
		);
		
		/**
		 * Blog Lists
		 */
		$panel_blog_lists = aoki_qodef_add_admin_panel(
			array(
				'page'  => '_blog_page',
				'name'  => 'panel_blog_lists',
				'title' => esc_html__( 'Blog Lists', 'aoki' )
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'name'          => 'blog_list_type',
				'type'          => 'select',
				'label'         => esc_html__( 'Blog Layout for Archive Pages', 'aoki' ),
				'description'   => esc_html__( 'Choose a default blog layout for archived blog post lists', 'aoki' ),
				'default_value' => 'standard',
				'parent'        => $panel_blog_lists,
				'options'       => $blog_list_type_options
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'name'          => 'archive_sidebar_layout',
				'type'          => 'select',
				'label'         => esc_html__( 'Sidebar Layout for Archive Pages', 'aoki' ),
				'description'   => esc_html__( 'Choose a sidebar layout for archived blog post lists', 'aoki' ),
				'default_value' => '',
				'parent'        => $panel_blog_lists,
                'options'       => aoki_qodef_get_custom_sidebars_options(),
			)
		);
		
		$aoki_custom_sidebars = aoki_qodef_get_custom_sidebars();
		if ( count( $aoki_custom_sidebars ) > 0 ) {
			aoki_qodef_add_admin_field(
				array(
					'name'        => 'archive_custom_sidebar_area',
					'type'        => 'selectblank',
					'label'       => esc_html__( 'Sidebar to Display for Archive Pages', 'aoki' ),
					'description' => esc_html__( 'Choose a sidebar to display on archived blog post lists. Default sidebar is "Sidebar Page"', 'aoki' ),
					'parent'      => $panel_blog_lists,
					'options'     => aoki_qodef_get_custom_sidebars(),
					'args'        => array(
						'select2' => true
					)
				)
			);
		}
		
		aoki_qodef_add_admin_field(
			array(
				'name'          => 'blog_masonry_layout',
				'type'          => 'select',
				'label'         => esc_html__( 'Masonry - Layout', 'aoki' ),
				'default_value' => 'in-grid',
				'description'   => esc_html__( 'Set masonry layout. Default is in grid.', 'aoki' ),
				'parent'        => $panel_blog_lists,
				'options'       => array(
					'in-grid'    => esc_html__( 'In Grid', 'aoki' ),
					'full-width' => esc_html__( 'Full Width', 'aoki' )
				)
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'name'          => 'blog_masonry_number_of_columns',
				'type'          => 'select',
				'label'         => esc_html__( 'Masonry - Number of Columns', 'aoki' ),
				'default_value' => 'three',
				'description'   => esc_html__( 'Set number of columns for your masonry blog lists. Default value is 4 columns', 'aoki' ),
				'parent'        => $panel_blog_lists,
				'options'       => array(
					'two'   => esc_html__( '2 Columns', 'aoki' ),
					'three' => esc_html__( '3 Columns', 'aoki' ),
					'four'  => esc_html__( '4 Columns', 'aoki' ),
					'five'  => esc_html__( '5 Columns', 'aoki' )
				)
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'name'          => 'blog_masonry_space_between_items',
				'type'          => 'select',
				'label'         => esc_html__( 'Masonry - Space Between Items', 'aoki' ),
				'description'   => esc_html__( 'Set space size between posts for your masonry blog lists. Default value is normal', 'aoki' ),
				'default_value' => 'normal',
				'options'       => aoki_qodef_get_space_between_items_array(),
				'parent'        => $panel_blog_lists
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'name'          => 'blog_list_featured_image_proportion',
				'type'          => 'select',
				'label'         => esc_html__( 'Masonry - Featured Image Proportion', 'aoki' ),
				'default_value' => 'fixed',
				'description'   => esc_html__( 'Choose type of proportions you want to use for featured images on masonry blog lists', 'aoki' ),
				'parent'        => $panel_blog_lists,
				'options'       => array(
					'fixed'    => esc_html__( 'Fixed', 'aoki' ),
					'original' => esc_html__( 'Original', 'aoki' )
				)
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'name'          => 'blog_pagination_type',
				'type'          => 'select',
				'label'         => esc_html__( 'Pagination Type', 'aoki' ),
				'description'   => esc_html__( 'Choose a pagination layout for Blog Lists', 'aoki' ),
				'parent'        => $panel_blog_lists,
				'default_value' => 'standard',
				'options'       => array(
					'standard'        => esc_html__( 'Standard', 'aoki' ),
					'load-more'       => esc_html__( 'Load More', 'aoki' ),
					'infinite-scroll' => esc_html__( 'Infinite Scroll', 'aoki' ),
					'no-pagination'   => esc_html__( 'No Pagination', 'aoki' )
				)
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'text',
				'name'          => 'number_of_chars',
				'default_value' => '40',
				'label'         => esc_html__( 'Number of Words in Excerpt', 'aoki' ),
				'description'   => esc_html__( 'Enter a number of words in excerpt (article summary). Default value is 40', 'aoki' ),
				'parent'        => $panel_blog_lists,
				'args'          => array(
					'col_width' => 3
				)
			)
		);
		
		/**
		 * Blog Single
		 */
		$panel_blog_single = aoki_qodef_add_admin_panel(
			array(
				'page'  => '_blog_page',
				'name'  => 'panel_blog_single',
				'title' => esc_html__( 'Blog Single', 'aoki' )
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'name'          => 'blog_single_sidebar_layout',
				'type'          => 'select',
				'label'         => esc_html__( 'Sidebar Layout', 'aoki' ),
				'description'   => esc_html__( 'Choose a sidebar layout for Blog Single pages', 'aoki' ),
				'default_value' => '',
				'parent'        => $panel_blog_single,
                'options'       => aoki_qodef_get_custom_sidebars_options()
			)
		);
		
		if ( count( $aoki_custom_sidebars ) > 0 ) {
			aoki_qodef_add_admin_field(
				array(
					'name'        => 'blog_single_custom_sidebar_area',
					'type'        => 'selectblank',
					'label'       => esc_html__( 'Sidebar to Display', 'aoki' ),
					'description' => esc_html__( 'Choose a sidebar to display on Blog Single pages. Default sidebar is "Sidebar"', 'aoki' ),
					'parent'      => $panel_blog_single,
					'options'     => aoki_qodef_get_custom_sidebars(),
					'args'        => array(
						'select2' => true
					)
				)
			);
		}
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'show_title_area_blog',
				'default_value' => '',
				'label'         => esc_html__( 'Show Title Area', 'aoki' ),
				'description'   => esc_html__( 'Enabling this option will show title area on single post pages', 'aoki' ),
				'parent'        => $panel_blog_single,
				'options'       => aoki_qodef_get_yes_no_select_array(),
				'args'          => array(
					'col_width' => 3
				)
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'name'          => 'blog_single_title_in_title_area',
				'type'          => 'yesno',
				'label'         => esc_html__( 'Show Post Title in Title Area', 'aoki' ),
				'description'   => esc_html__( 'Enabling this option will show post title in title area on single post pages', 'aoki' ),
				'parent'        => $panel_blog_single,
				'default_value' => 'no'
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'name'          => 'blog_single_related_posts',
				'type'          => 'yesno',
				'label'         => esc_html__( 'Show Related Posts', 'aoki' ),
				'description'   => esc_html__( 'Enabling this option will show related posts on single post pages', 'aoki' ),
				'parent'        => $panel_blog_single,
				'default_value' => 'no'
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'name'          => 'blog_single_comments',
				'type'          => 'yesno',
				'label'         => esc_html__( 'Show Comments Form', 'aoki' ),
				'description'   => esc_html__( 'Enabling this option will show comments form on single post pages', 'aoki' ),
				'parent'        => $panel_blog_single,
				'default_value' => 'yes'
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'yesno',
				'name'          => 'blog_single_navigation',
				'default_value' => 'no',
				'label'         => esc_html__( 'Enable Prev/Next Single Post Navigation Links', 'aoki' ),
				'description'   => esc_html__( 'Enable navigation links through the blog posts (left and right arrows will appear)', 'aoki' ),
				'parent'        => $panel_blog_single,
				'args'          => array(
					'dependence'             => true,
					'dependence_hide_on_yes' => '',
					'dependence_show_on_yes' => '#qodef_qodef_blog_single_navigation_container'
				)
			)
		);
		
		$blog_single_navigation_container = aoki_qodef_add_admin_container(
			array(
				'name'            => 'qodef_blog_single_navigation_container',
				'hidden_property' => 'blog_single_navigation',
				'hidden_value'    => 'no',
				'parent'          => $panel_blog_single,
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'yesno',
				'name'          => 'blog_navigation_through_same_category',
				'default_value' => 'no',
				'label'         => esc_html__( 'Enable Navigation Only in Current Category', 'aoki' ),
				'description'   => esc_html__( 'Limit your navigation only through current category', 'aoki' ),
				'parent'        => $blog_single_navigation_container,
				'args'          => array(
					'col_width' => 3
				)
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'yesno',
				'name'          => 'blog_author_info',
				'default_value' => 'yes',
				'label'         => esc_html__( 'Show Author Info Box', 'aoki' ),
				'description'   => esc_html__( 'Enabling this option will display author name and descriptions on single post pages', 'aoki' ),
				'parent'        => $panel_blog_single,
				'args'          => array(
					'dependence'             => true,
					'dependence_hide_on_yes' => '',
					'dependence_show_on_yes' => '#qodef_qodef_blog_single_author_info_container'
				)
			)
		);
		
		$blog_single_author_info_container = aoki_qodef_add_admin_container(
			array(
				'name'            => 'qodef_blog_single_author_info_container',
				'hidden_property' => 'blog_author_info',
				'hidden_value'    => 'no',
				'parent'          => $panel_blog_single,
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'yesno',
				'name'          => 'blog_author_info_email',
				'default_value' => 'no',
				'label'         => esc_html__( 'Show Author Email', 'aoki' ),
				'description'   => esc_html__( 'Enabling this option will show author email', 'aoki' ),
				'parent'        => $blog_single_author_info_container,
				'args'          => array(
					'col_width' => 3
				)
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'yesno',
				'name'          => 'blog_single_author_social',
				'default_value' => 'yes',
				'label'         => esc_html__( 'Show Author Social Icons', 'aoki' ),
				'description'   => esc_html__( 'Enabling this option will show author social icons on single post pages', 'aoki' ),
				'parent'        => $blog_single_author_info_container,
				'args'          => array(
					'col_width' => 3
				)
			)
		);
		
		do_action( 'aoki_qodef_blog_single_options_map', $panel_blog_single );
	}
	
	add_action( 'aoki_qodef_options_map', 'aoki_qodef_blog_options_map', 10 );
}