<?php

if ( ! function_exists( 'aoki_qodef_get_search_types_options' ) ) {
    function aoki_qodef_get_search_types_options() {
        $search_type_options = apply_filters( 'aoki_qodef_search_type_global_option', $search_type_options = array() );

        return $search_type_options;
    }
}

if ( ! function_exists( 'aoki_qodef_search_options_map' ) ) {
	function aoki_qodef_search_options_map() {
		
		aoki_qodef_add_admin_page(
			array(
				'slug'  => '_search_page',
				'title' => esc_html__( 'Search', 'aoki' ),
				'icon'  => 'fa fa-search'
			)
		);
		
		$search_page_panel = aoki_qodef_add_admin_panel(
			array(
				'title' => esc_html__( 'Search Page', 'aoki' ),
				'name'  => 'search_template',
				'page'  => '_search_page'
			)
		);
		
		aoki_qodef_add_admin_field( array(
			'name'          => 'search_page_layout',
			'type'          => 'select',
			'label'         => esc_html__( 'Layout', 'aoki' ),
			'default_value' => 'in-grid',
			'description'   => esc_html__( 'Set layout. Default is in grid.', 'aoki' ),
			'parent'        => $search_page_panel,
			'options'       => array(
				'in-grid'    => esc_html__( 'In Grid', 'aoki' ),
				'full-width' => esc_html__( 'Full Width', 'aoki' )
			)
		) );
		
		aoki_qodef_add_admin_field( array(
			'name'          => 'search_page_sidebar_layout',
			'type'          => 'select',
			'label'         => esc_html__( 'Sidebar Layout', 'aoki' ),
			'description'   => esc_html__( "Choose a sidebar layout for search page", 'aoki' ),
			'default_value' => 'no-sidebar',
			'options'       => aoki_qodef_get_custom_sidebars_options(),
			'parent'        => $search_page_panel
		) );
		
		$aoki_custom_sidebars = aoki_qodef_get_custom_sidebars();
		if ( count( $aoki_custom_sidebars ) > 0 ) {
			aoki_qodef_add_admin_field( array(
				'name'        => 'search_custom_sidebar_area',
				'type'        => 'selectblank',
				'label'       => esc_html__( 'Sidebar to Display', 'aoki' ),
				'description' => esc_html__( 'Choose a sidebar to display on search page. Default sidebar is "Sidebar"', 'aoki' ),
				'parent'      => $search_page_panel,
				'options'     => $aoki_custom_sidebars,
				'args'        => array(
					'select2' => true
				)
			) );
		}
		
		$search_panel = aoki_qodef_add_admin_panel(
			array(
				'title' => esc_html__( 'Search', 'aoki' ),
				'name'  => 'search',
				'page'  => '_search_page'
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'parent'        => $search_panel,
				'type'          => 'select',
				'name'          => 'search_icon_pack',
				'default_value' => 'font_awesome',
				'label'         => esc_html__( 'Search Icon Pack', 'aoki' ),
				'description'   => esc_html__( 'Choose icon pack for search icon', 'aoki' ),
				'options'       => aoki_qodef_icon_collections()->getIconCollectionsExclude( array( 'linea_icons' ) )
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'parent'        => $search_panel,
				'type'          => 'yesno',
				'name'          => 'search_in_grid',
				'default_value' => 'yes',
				'label'         => esc_html__( 'Enable Grid Layout', 'aoki' ),
				'description'   => esc_html__( 'Set search area to be in grid. (Applied for Search covers header and Slide from Window Top types.', 'aoki' ),
			)
		);
		
		aoki_qodef_add_admin_section_title(
			array(
				'parent' => $search_panel,
				'name'   => 'initial_header_icon_title',
				'title'  => esc_html__( 'Initial Search Icon in Header', 'aoki' )
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'parent'        => $search_panel,
				'type'          => 'text',
				'name'          => 'header_search_icon_size',
				'default_value' => '',
				'label'         => esc_html__( 'Icon Size', 'aoki' ),
				'description'   => esc_html__( 'Set size for icon', 'aoki' ),
				'args'          => array(
					'col_width' => 3,
					'suffix'    => 'px'
				)
			)
		);
		
		$search_icon_color_group = aoki_qodef_add_admin_group(
			array(
				'parent'      => $search_panel,
				'title'       => esc_html__( 'Icon Colors', 'aoki' ),
				'description' => esc_html__( 'Define color style for icon', 'aoki' ),
				'name'        => 'search_icon_color_group'
			)
		);
		
		$search_icon_color_row = aoki_qodef_add_admin_row(
			array(
				'parent' => $search_icon_color_group,
				'name'   => 'search_icon_color_row'
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'parent' => $search_icon_color_row,
				'type'   => 'colorsimple',
				'name'   => 'header_search_icon_color',
				'label'  => esc_html__( 'Color', 'aoki' )
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'parent' => $search_icon_color_row,
				'type'   => 'colorsimple',
				'name'   => 'header_search_icon_hover_color',
				'label'  => esc_html__( 'Hover Color', 'aoki' )
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'parent'        => $search_panel,
				'type'          => 'yesno',
				'name'          => 'enable_search_icon_text',
				'default_value' => 'no',
				'label'         => esc_html__( 'Enable Search Icon Text', 'aoki' ),
				'description'   => esc_html__( "Enable this option to show 'Search' text next to search icon in header", 'aoki' ),
				'args'          => array(
					'dependence'             => true,
					'dependence_hide_on_yes' => '',
					'dependence_show_on_yes' => '#qodef_enable_search_icon_text_container'
				)
			)
		);
		
		$enable_search_icon_text_container = aoki_qodef_add_admin_container(
			array(
				'parent'          => $search_panel,
				'name'            => 'enable_search_icon_text_container',
				'hidden_property' => 'enable_search_icon_text',
				'hidden_value'    => 'no'
			)
		);
		
		$enable_search_icon_text_group = aoki_qodef_add_admin_group(
			array(
				'parent'      => $enable_search_icon_text_container,
				'title'       => esc_html__( 'Search Icon Text', 'aoki' ),
				'name'        => 'enable_search_icon_text_group',
				'description' => esc_html__( 'Define style for search icon text', 'aoki' )
			)
		);
		
		$enable_search_icon_text_row = aoki_qodef_add_admin_row(
			array(
				'parent' => $enable_search_icon_text_group,
				'name'   => 'enable_search_icon_text_row'
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'parent' => $enable_search_icon_text_row,
				'type'   => 'colorsimple',
				'name'   => 'search_icon_text_color',
				'label'  => esc_html__( 'Text Color', 'aoki' )
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'parent' => $enable_search_icon_text_row,
				'type'   => 'colorsimple',
				'name'   => 'search_icon_text_color_hover',
				'label'  => esc_html__( 'Text Hover Color', 'aoki' )
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'parent'        => $enable_search_icon_text_row,
				'type'          => 'textsimple',
				'name'          => 'search_icon_text_font_size',
				'label'         => esc_html__( 'Font Size', 'aoki' ),
				'default_value' => '',
				'args'          => array(
					'suffix' => 'px'
				)
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'parent'        => $enable_search_icon_text_row,
				'type'          => 'textsimple',
				'name'          => 'search_icon_text_line_height',
				'label'         => esc_html__( 'Line Height', 'aoki' ),
				'default_value' => '',
				'args'          => array(
					'suffix' => 'px'
				)
			)
		);
		
		$enable_search_icon_text_row2 = aoki_qodef_add_admin_row(
			array(
				'parent' => $enable_search_icon_text_group,
				'name'   => 'enable_search_icon_text_row2',
				'next'   => true
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'parent'        => $enable_search_icon_text_row2,
				'type'          => 'selectblanksimple',
				'name'          => 'search_icon_text_text_transform',
				'label'         => esc_html__( 'Text Transform', 'aoki' ),
				'default_value' => '',
				'options'       => aoki_qodef_get_text_transform_array()
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'parent'        => $enable_search_icon_text_row2,
				'type'          => 'fontsimple',
				'name'          => 'search_icon_text_google_fonts',
				'label'         => esc_html__( 'Font Family', 'aoki' ),
				'default_value' => '-1',
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'parent'        => $enable_search_icon_text_row2,
				'type'          => 'selectblanksimple',
				'name'          => 'search_icon_text_font_style',
				'label'         => esc_html__( 'Font Style', 'aoki' ),
				'default_value' => '',
				'options'       => aoki_qodef_get_font_style_array(),
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'parent'        => $enable_search_icon_text_row2,
				'type'          => 'selectblanksimple',
				'name'          => 'search_icon_text_font_weight',
				'label'         => esc_html__( 'Font Weight', 'aoki' ),
				'default_value' => '',
				'options'       => aoki_qodef_get_font_weight_array(),
			)
		);
		
		$enable_search_icon_text_row3 = aoki_qodef_add_admin_row(
			array(
				'parent' => $enable_search_icon_text_group,
				'name'   => 'enable_search_icon_text_row3',
				'next'   => true
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'parent'        => $enable_search_icon_text_row3,
				'type'          => 'textsimple',
				'name'          => 'search_icon_text_letter_spacing',
				'label'         => esc_html__( 'Letter Spacing', 'aoki' ),
				'default_value' => '',
				'args'          => array(
					'suffix' => 'px'
				)
			)
		);
	}
	
	add_action( 'aoki_qodef_options_map', 'aoki_qodef_search_options_map', 12 );
}