<?php

/**
 * Force Visual Composer to initialize as "built into the theme". This will hide certain tabs under the Settings->Visual Composer page
 */
if ( function_exists( 'vc_set_as_theme' ) ) {
	vc_set_as_theme( true );
}

/**
 * Change path for overridden templates
 */
if ( function_exists( 'vc_set_shortcodes_templates_dir' ) ) {
	$dir = QODE_ROOT_DIR . '/vc-templates';
	vc_set_shortcodes_templates_dir( $dir );
}

if ( ! function_exists( 'aoki_qodef_configure_visual_composer_frontend_editor' ) ) {
	/**
	 * Configuration for Visual Composer FrontEnd Editor
	 * Hooks on vc_after_init action
	 */
	function aoki_qodef_configure_visual_composer_frontend_editor() {
		/**
		 * Remove frontend editor
		 */
		if ( function_exists( 'vc_disable_frontend' ) ) {
			vc_disable_frontend();
		}
	}
	
	add_action( 'vc_after_init', 'aoki_qodef_configure_visual_composer_frontend_editor' );
}

if ( ! function_exists( 'aoki_qodef_vc_row_map' ) ) {
	/**
	 * Map VC Row shortcode
	 * Hooks on vc_after_init action
	 */
	function aoki_qodef_vc_row_map() {
		
		/******* VC Row shortcode - begin *******/
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'dropdown',
				'param_name' => 'row_content_width',
				'heading'    => esc_html__( 'Select Row Content Width', 'aoki' ),
				'value'      => array(
					esc_html__( 'Full Width', 'aoki' ) => 'full-width',
					esc_html__( 'In Grid', 'aoki' )    => 'grid'
				),
				'group'      => esc_html__( 'Select Settings', 'aoki' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'        => 'textfield',
				'param_name'  => 'anchor',
				'heading'     => esc_html__( 'Select Anchor ID', 'aoki' ),
				'description' => esc_html__( 'For example "home"', 'aoki' ),
				'group'       => esc_html__( 'Select Settings', 'aoki' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'colorpicker',
				'param_name' => 'simple_background_color',
				'heading'    => esc_html__( 'Select Background Color', 'aoki' ),
				'group'      => esc_html__( 'Select Settings', 'aoki' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'attach_image',
				'param_name' => 'simple_background_image',
				'heading'    => esc_html__( 'Select Background Image', 'aoki' ),
				'group'      => esc_html__( 'Select Settings', 'aoki' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'        => 'dropdown',
				'param_name'  => 'disable_background_image',
				'heading'     => esc_html__( 'Select Disable Background Image', 'aoki' ),
				'value'       => array(
					esc_html__( 'Never', 'aoki' )        => '',
					esc_html__( 'Below 1280px', 'aoki' ) => '1280',
					esc_html__( 'Below 1024px', 'aoki' ) => '1024',
					esc_html__( 'Below 768px', 'aoki' )  => '768',
					esc_html__( 'Below 680px', 'aoki' )  => '680',
					esc_html__( 'Below 480px', 'aoki' )  => '480'
				),
				'save_always' => true,
				'description' => esc_html__( 'Choose on which stage you hide row background image', 'aoki' ),
				'dependency'  => array( 'element' => 'simple_background_image', 'not_empty' => true ),
				'group'       => esc_html__( 'Select Settings', 'aoki' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'attach_image',
				'param_name' => 'parallax_background_image',
				'heading'    => esc_html__( 'Select Parallax Background Image', 'aoki' ),
				'group'      => esc_html__( 'Select Settings', 'aoki' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'        => 'textfield',
				'param_name'  => 'parallax_bg_speed',
				'heading'     => esc_html__( 'Select Parallax Speed', 'aoki' ),
				'description' => esc_html__( 'Set your parallax speed. Default value is 1.', 'aoki' ),
				'dependency'  => array( 'element' => 'parallax_background_image', 'not_empty' => true ),
				'group'       => esc_html__( 'Select Settings', 'aoki' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'textfield',
				'param_name' => 'parallax_bg_height',
				'heading'    => esc_html__( 'Select Parallax Section Height (px)', 'aoki' ),
				'dependency' => array( 'element' => 'parallax_background_image', 'not_empty' => true ),
				'group'      => esc_html__( 'Select Settings', 'aoki' )
			)
		);
		
		vc_add_param( 'vc_row',
			array(
				'type'       => 'dropdown',
				'param_name' => 'content_text_aligment',
				'heading'    => esc_html__( 'Select Content Aligment', 'aoki' ),
				'value'      => array(
					esc_html__( 'Default', 'aoki' ) => '',
					esc_html__( 'Left', 'aoki' )    => 'left',
					esc_html__( 'Center', 'aoki' )  => 'center',
					esc_html__( 'Right', 'aoki' )   => 'right'
				),
				'group'      => esc_html__( 'Select Settings', 'aoki' )
			)
		);

        vc_add_param( 'vc_row',
            array(
                'type'       => 'textfield',
                'param_name' => 'row_background_text_1',
                'heading'    => esc_html__( 'Select Background Text 1', 'aoki' ),
                'group'      => esc_html__( 'Select Settings', 'aoki' )
            )
        );

        vc_add_param( 'vc_row',
            array(
                'type'       => 'textfield',
                'param_name' => 'row_background_text_2',
                'heading'    => esc_html__( 'Select Background Text 2', 'aoki' ),
                'dependency' => array( 'element' => 'row_background_text_1', 'not_empty' => true ),
                'group'      => esc_html__( 'Select Settings', 'aoki' )
            )
        );

        vc_add_param( 'vc_row',
            array(
                'type'       => 'textfield',
                'param_name' => 'row_background_text_size',
                'heading'    => esc_html__( 'Select Background Text Size', 'aoki' ),
                'description' => esc_html__( 'Set the background text size in px or em', 'aoki' ),
                'dependency' => array( 'element' => 'row_background_text_1', 'not_empty' => true ),
                'group'      => esc_html__( 'Select Settings', 'aoki' )
            )
        );

        vc_add_param( 'vc_row',
            array(
                'type'       => 'textfield',
                'param_name' => 'row_background_text_size_1440',
                'heading'    => esc_html__( 'Select Background Text Size 1280px-1440px', 'aoki' ),
                'description' => esc_html__( 'Set the background text size in px or em', 'aoki' ),
                'dependency' => array( 'element' => 'row_background_text_1', 'not_empty' => true ),
                'group'      => esc_html__( 'Select Settings', 'aoki' )
            )
        );

        vc_add_param( 'vc_row',
            array(
                'type'       => 'textfield',
                'param_name' => 'row_background_text_size_1280',
                'heading'    => esc_html__( 'Select Background Text Size 1024px-1280px', 'aoki' ),
                'description' => esc_html__( 'Set the background text size in px or em', 'aoki' ),
                'dependency' => array( 'element' => 'row_background_text_1', 'not_empty' => true ),
                'group'      => esc_html__( 'Select Settings', 'aoki' )
            )
        );

        vc_add_param( 'vc_row',
            array(
                'type'       => 'colorpicker',
                'param_name' => 'row_background_text_color',
                'heading'    => esc_html__( 'Select Background Text Color', 'aoki' ),
                'dependency' => array( 'element' => 'row_background_text_1', 'not_empty' => true ),
                'group'      => esc_html__( 'Select Settings', 'aoki' )
            )
        );

        vc_add_param( 'vc_row',
            array(
                'type'       => 'dropdown',
                'param_name' => 'row_background_text_align',
                'heading'    => esc_html__( 'Select Background Text Align', 'aoki' ),
                'value'      => array(
                    esc_html__( 'Default', 'aoki' ) => '',
                    esc_html__( 'Left', 'aoki' )    => 'left',
                    esc_html__( 'Center', 'aoki' )  => 'center',
                    esc_html__( 'Right', 'aoki' )   => 'right'
                ),
                'dependency' => array( 'element' => 'row_background_text_1', 'not_empty' => true ),
                'group'      => esc_html__( 'Select Settings', 'aoki' )
            )
        );

        vc_add_param( 'vc_row',
            array(
                'type'       => 'dropdown',
                'param_name' => 'row_background_text_vertical_align',
                'heading'    => esc_html__( 'Select Background Vertical Align', 'aoki' ),
                'value'      => array(
                    esc_html__( 'Middle', 'aoki' )   => 'middle',
                    esc_html__( 'Top', 'aoki' )      => 'top',
                    esc_html__( 'Bottom', 'aoki' )   => 'bottom'
                ),
                'dependency' => array( 'element' => 'row_background_text_1', 'not_empty' => true ),
                'group'      => esc_html__( 'Select Settings', 'aoki' )
            )
        );

        vc_add_param( 'vc_row',
            array(
                'type'       => 'textfield',
                'param_name' => 'row_background_text_padding_top',
                'heading'    => esc_html__( 'Select Background Text Top Padding', 'aoki' ),
                'description' => esc_html__( 'Set the value of top padding in px or %', 'aoki' ),
                'dependency' => array( 'element' => 'row_background_text_1', 'not_empty' => true ),
                'group'      => esc_html__( 'Select Settings', 'aoki' )
            )
        );

        vc_add_param( 'vc_row',
            array(
                'type'       => 'dropdown',
                'param_name' => 'row_background_text_animation',
                'heading'    => esc_html__( 'Animate Background Text', 'aoki' ),
				'value'      => array_flip( aoki_qodef_get_yes_no_select_array(false, true) ),
                'dependency' => array( 'element' => 'row_background_text_1', 'not_empty' => true ),
                'description'    => esc_html__( 'Animate background text when row appears in viewport', 'aoki' ),
                'group'      => esc_html__( 'Select Settings', 'aoki' )
            )
        );
		
		/******* VC Row shortcode - end *******/
		
		/******* VC Row Inner shortcode - begin *******/
		
		vc_add_param( 'vc_row_inner',
			array(
				'type'       => 'dropdown',
				'param_name' => 'row_content_width',
				'heading'    => esc_html__( 'Select Row Content Width', 'aoki' ),
				'value'      => array(
					esc_html__( 'Full Width', 'aoki' ) => 'full-width',
					esc_html__( 'In Grid', 'aoki' )    => 'grid'
				),
				'group'      => esc_html__( 'Select Settings', 'aoki' )
			)
		);
		
		vc_add_param( 'vc_row_inner',
			array(
				'type'       => 'colorpicker',
				'param_name' => 'simple_background_color',
				'heading'    => esc_html__( 'Select Background Color', 'aoki' ),
				'group'      => esc_html__( 'Select Settings', 'aoki' )
			)
		);
		
		vc_add_param( 'vc_row_inner',
			array(
				'type'       => 'attach_image',
				'param_name' => 'simple_background_image',
				'heading'    => esc_html__( 'Select Background Image', 'aoki' ),
				'group'      => esc_html__( 'Select Settings', 'aoki' )
			)
		);
		
		vc_add_param( 'vc_row_inner',
			array(
				'type'        => 'dropdown',
				'param_name'  => 'disable_background_image',
				'heading'     => esc_html__( 'Select Disable Background Image', 'aoki' ),
				'value'       => array(
					esc_html__( 'Never', 'aoki' )        => '',
					esc_html__( 'Below 1280px', 'aoki' ) => '1280',
					esc_html__( 'Below 1024px', 'aoki' ) => '1024',
					esc_html__( 'Below 768px', 'aoki' )  => '768',
					esc_html__( 'Below 680px', 'aoki' )  => '680',
					esc_html__( 'Below 480px', 'aoki' )  => '480'
				),
				'save_always' => true,
				'description' => esc_html__( 'Choose on which stage you hide row background image', 'aoki' ),
				'dependency'  => array( 'element' => 'simple_background_image', 'not_empty' => true ),
				'group'       => esc_html__( 'Select Settings', 'aoki' )
			)
		);
		
		vc_add_param( 'vc_row_inner',
			array(
				'type'       => 'dropdown',
				'param_name' => 'content_text_aligment',
				'heading'    => esc_html__( 'Select Content Aligment', 'aoki' ),
				'value'      => array(
					esc_html__( 'Default', 'aoki' ) => '',
					esc_html__( 'Left', 'aoki' )    => 'left',
					esc_html__( 'Center', 'aoki' )  => 'center',
					esc_html__( 'Right', 'aoki' )   => 'right'
				),
				'group'      => esc_html__( 'Select Settings', 'aoki' )
			)
		);
		
		/******* VC Row Inner shortcode - end *******/
		
		/******* VC Revolution Slider shortcode - begin *******/
		
		if ( aoki_qodef_revolution_slider_installed() ) {
			
			vc_add_param( 'rev_slider_vc',
				array(
					'type'        => 'dropdown',
					'param_name'  => 'enable_paspartu',
					'heading'     => esc_html__( 'Select Enable Passepartout', 'aoki' ),
					'value'       => array_flip( aoki_qodef_get_yes_no_select_array( false ) ),
					'save_always' => true,
					'group'       => esc_html__( 'Select Settings', 'aoki' )
				)
			);
			
			vc_add_param( 'rev_slider_vc',
				array(
					'type'        => 'dropdown',
					'param_name'  => 'paspartu_size',
					'heading'     => esc_html__( 'Select Passepartout Size', 'aoki' ),
					'value'       => array(
						esc_html__( 'Tiny', 'aoki' )   => 'tiny',
						esc_html__( 'Small', 'aoki' )  => 'small',
						esc_html__( 'Normal', 'aoki' ) => 'normal',
						esc_html__( 'Large', 'aoki' )  => 'large'
					),
					'save_always' => true,
					'dependency'  => array( 'element' => 'enable_paspartu', 'value' => array( 'yes' ) ),
					'group'       => esc_html__( 'Select Settings', 'aoki' )
				)
			);
			
			vc_add_param( 'rev_slider_vc',
				array(
					'type'        => 'dropdown',
					'param_name'  => 'disable_side_paspartu',
					'heading'     => esc_html__( 'Select Disable Side Passepartout', 'aoki' ),
					'value'       => array_flip( aoki_qodef_get_yes_no_select_array( false ) ),
					'save_always' => true,
					'dependency'  => array( 'element' => 'enable_paspartu', 'value' => array( 'yes' ) ),
					'group'       => esc_html__( 'Select Settings', 'aoki' )
				)
			);
			
			vc_add_param( 'rev_slider_vc',
				array(
					'type'        => 'dropdown',
					'param_name'  => 'disable_top_paspartu',
					'heading'     => esc_html__( 'Select Disable Top Passepartout', 'aoki' ),
					'value'       => array_flip( aoki_qodef_get_yes_no_select_array( false ) ),
					'save_always' => true,
					'dependency'  => array( 'element' => 'enable_paspartu', 'value' => array( 'yes' ) ),
					'group'       => esc_html__( 'Select Settings', 'aoki' )
				)
			);
		}
		
		/******* VC Revolution Slider shortcode - end *******/
	}
	
	add_action( 'vc_after_init', 'aoki_qodef_vc_row_map' );
}