<?php

if ( ! function_exists( 'aoki_qodef_woocommerce_options_map' ) ) {
	
	/**
	 * Add Woocommerce options page
	 */
	function aoki_qodef_woocommerce_options_map() {
		
		aoki_qodef_add_admin_page(
			array(
				'slug'  => '_woocommerce_page',
				'title' => esc_html__( 'Woocommerce', 'aoki' ),
				'icon'  => 'fa fa-shopping-cart'
			)
		);
		
		/**
		 * Product List Settings
		 */
		$panel_product_list = aoki_qodef_add_admin_panel(
			array(
				'page'  => '_woocommerce_page',
				'name'  => 'panel_product_list',
				'title' => esc_html__( 'Product List', 'aoki' )
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'qodef_woo_product_list_columns',
				'label'         => esc_html__( 'Product List Columns', 'aoki' ),
				'default_value' => 'qodef-woocommerce-columns-4',
				'description'   => esc_html__( 'Choose number of columns for product listing and related products on single product', 'aoki' ),
				'options'       => array(
					'qodef-woocommerce-columns-3' => esc_html__( '3 Columns', 'aoki' ),
					'qodef-woocommerce-columns-4' => esc_html__( '4 Columns', 'aoki' )
				),
				'parent'        => $panel_product_list,
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'qodef_woo_product_list_columns_space',
				'label'         => esc_html__( 'Space Between Items', 'aoki' ),
				'description'   => esc_html__( 'Select space between items for product listing and related products on single product', 'aoki' ),
				'default_value' => 'normal',
				'options'       => aoki_qodef_get_space_between_items_array(),
				'parent'        => $panel_product_list,
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'text',
				'name'          => 'qodef_woo_products_per_page',
				'label'         => esc_html__( 'Number of products per page', 'aoki' ),
				'description'   => esc_html__( 'Set number of products on shop page', 'aoki' ),
				'parent'        => $panel_product_list,
				'args'          => array(
					'col_width' => 3
				)
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'qodef_products_list_title_tag',
				'label'         => esc_html__( 'Products Title Tag', 'aoki' ),
				'default_value' => 'h5',
				'options'       => aoki_qodef_get_title_tag(),
				'parent'        => $panel_product_list,
			)
		);
		
		/**
		 * Single Product Settings
		 */
		$panel_single_product = aoki_qodef_add_admin_panel(
			array(
				'page'  => '_woocommerce_page',
				'name'  => 'panel_single_product',
				'title' => esc_html__( 'Single Product', 'aoki' )
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'show_title_area_woo',
				'default_value' => '',
				'label'         => esc_html__( 'Show Title Area', 'aoki' ),
				'description'   => esc_html__( 'Enabling this option will show title area on single post pages', 'aoki' ),
				'parent'        => $panel_single_product,
				'options'       => aoki_qodef_get_yes_no_select_array(),
				'args'          => array(
					'col_width' => 3
				)
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'qodef_single_product_title_tag',
				'default_value' => 'h2',
				'label'         => esc_html__( 'Single Product Title Tag', 'aoki' ),
				'options'       => aoki_qodef_get_title_tag(),
				'parent'        => $panel_single_product,
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'woo_number_of_thumb_images',
				'default_value' => '4',
				'label'         => esc_html__( 'Number of Thumbnail Images per Row', 'aoki' ),
				'options'       => array(
					'4' => esc_html__( 'Four', 'aoki' ),
					'3' => esc_html__( 'Three', 'aoki' ),
					'2' => esc_html__( 'Two', 'aoki' )
				),
				'parent'        => $panel_single_product
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'woo_set_thumb_images_position',
				'default_value' => 'below-image',
				'label'         => esc_html__( 'Set Thumbnail Images Position', 'aoki' ),
				'options'       => array(
					'below-image'  => esc_html__( 'Below Featured Image', 'aoki' ),
					'on-left-side' => esc_html__( 'On The Left Side Of Featured Image', 'aoki' )
				),
				'parent'        => $panel_single_product
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'woo_enable_single_product_zoom_image',
				'default_value' => 'no',
				'label'         => esc_html__( 'Enable Zoom Maginfier', 'aoki' ),
				'description'   => esc_html__( 'Enabling this option will show magnifier image on featured image hover', 'aoki' ),
				'parent'        => $panel_single_product,
				'options'       => aoki_qodef_get_yes_no_select_array( false ),
				'args'          => array(
					'col_width' => 3
				)
			)
		);
		
		aoki_qodef_add_admin_field(
			array(
				'type'          => 'select',
				'name'          => 'woo_set_single_images_behavior',
				'default_value' => 'pretty-photo',
				'label'         => esc_html__( 'Set Images Behavior', 'aoki' ),
				'options'       => array(
					'pretty-photo' => esc_html__( 'Pretty Photo Lightbox', 'aoki' ),
					'photo-swipe'  => esc_html__( 'Photo Swipe Lightbox', 'aoki' )
				),
				'parent'        => $panel_single_product
			)
		);
	}
	
	add_action( 'aoki_qodef_options_map', 'aoki_qodef_woocommerce_options_map', 17 );
}