<?php
include_once get_template_directory() . '/theme-includes.php';

if ( !function_exists('aoki_qodef_styles') ) {
	/**
	 * Function that includes theme's core styles
	 */
	function aoki_qodef_styles() {
		
		//include theme's core styles
		wp_enqueue_style('aoki-qodef-default-style', QODE_ROOT . '/style.css');
		wp_enqueue_style('aoki-qodef-modules', QODE_ASSETS_ROOT . '/css/modules.min.css');
		
		aoki_qodef_icon_collections()->enqueueStyles();
		
		wp_enqueue_style('wp-mediaelement');
		
		do_action('aoki_qodef_enqueue_third_party_styles');
		
		//is woocommerce installed?
		if ( aoki_qodef_is_woocommerce_installed() && aoki_qodef_load_woo_assets() ) {
			//include theme's woocommerce styles
			wp_enqueue_style('aoki-qodef-woo', QODE_ASSETS_ROOT . '/css/woocommerce.min.css');
		}
		
		//define files after which style dynamic needs to be included. It should be included last so it can override other files
		$style_dynamic_deps_array = apply_filters('aoki_qodef_style_dynamic_deps', array());
		
		if ( file_exists(QODE_ROOT_DIR . '/assets/css/style_dynamic.css') && aoki_qodef_is_css_folder_writable() && !is_multisite() ) {
			wp_enqueue_style('aoki-qodef-style-dynamic', QODE_ASSETS_ROOT . '/css/style_dynamic.css', $style_dynamic_deps_array, filemtime(QODE_ROOT_DIR . '/assets/css/style_dynamic.css')); //it must be included after woocommerce styles so it can override it
		} else if ( file_exists(QODE_ROOT_DIR . '/assets/css/style_dynamic_ms_id_' . aoki_qodef_get_multisite_blog_id() . '.css') && aoki_qodef_is_css_folder_writable() && is_multisite() ) {
			wp_enqueue_style('aoki-qodef-style-dynamic', QODE_ASSETS_ROOT . '/css/style_dynamic_ms_id_' . aoki_qodef_get_multisite_blog_id() . '.css', $style_dynamic_deps_array, filemtime(QODE_ROOT_DIR . '/assets/css/style_dynamic_ms_id_' . aoki_qodef_get_multisite_blog_id() . '.css')); //it must be included after woocommerce styles so it can override it
		}
		
		//is responsive option turned on?
		if ( aoki_qodef_is_responsive_on() ) {
			wp_enqueue_style('aoki-qodef-modules-responsive', QODE_ASSETS_ROOT . '/css/modules-responsive.min.css');
			
			//is woocommerce installed?
			if ( aoki_qodef_is_woocommerce_installed() && aoki_qodef_load_woo_assets() ) {
				//include theme's woocommerce responsive styles
				wp_enqueue_style('aoki-odef-woo-responsive', QODE_ASSETS_ROOT . '/css/woocommerce-responsive.min.css');
			}
			
			//include proper styles
			if ( file_exists(QODE_ROOT_DIR . '/assets/css/style_dynamic_responsive.css') && aoki_qodef_is_css_folder_writable() && !is_multisite() ) {
				wp_enqueue_style('aoki-qodef-style-dynamic-responsive', QODE_ASSETS_ROOT . '/css/style_dynamic_responsive.css', array(), filemtime(QODE_ROOT_DIR . '/assets/css/style_dynamic_responsive.css'));
			} else if ( file_exists(QODE_ROOT_DIR . '/assets/css/style_dynamic_responsive_ms_id_' . aoki_qodef_get_multisite_blog_id() . '.css') && aoki_qodef_is_css_folder_writable() && is_multisite() ) {
				wp_enqueue_style('aoki-qodef-style-dynamic-responsive', QODE_ASSETS_ROOT . '/css/style_dynamic_responsive_ms_id_' . aoki_qodef_get_multisite_blog_id() . '.css', array(), filemtime(QODE_ROOT_DIR . '/assets/css/style_dynamic_responsive_ms_id_' . aoki_qodef_get_multisite_blog_id() . '.css'));
			}
		}
	}
	
	add_action('wp_enqueue_scripts', 'aoki_qodef_styles');
}

if ( !function_exists('aoki_qodef_google_fonts_styles') ) {
	/**
	 * Function that includes google fonts defined anywhere in the theme
	 */
	function aoki_qodef_google_fonts_styles() {
		$font_simple_field_array = aoki_qodef_options()->getOptionsByType('fontsimple');
		if ( !(is_array($font_simple_field_array) && count($font_simple_field_array) > 0) ) {
			$font_simple_field_array = array();
		}
		
		$font_field_array = aoki_qodef_options()->getOptionsByType('font');
		if ( !(is_array($font_field_array) && count($font_field_array) > 0) ) {
			$font_field_array = array();
		}
		
		$available_font_options = array_merge($font_simple_field_array, $font_field_array);
		
		$google_font_weight_array = aoki_qodef_options()->getOptionValue('google_font_weight');
		if ( !empty($google_font_weight_array) ) {
			$google_font_weight_array = array_slice(aoki_qodef_options()->getOptionValue('google_font_weight'), 1);
		}
		
		$font_weight_str = '200,300,400,500,600,700,800,900';
		if ( !empty($google_font_weight_array) && $google_font_weight_array !== '' ) {
			$font_weight_str = implode(',', $google_font_weight_array);
		}
		
		$google_font_subset_array = aoki_qodef_options()->getOptionValue('google_font_subset');
		if ( !empty($google_font_subset_array) ) {
			$google_font_subset_array = array_slice(aoki_qodef_options()->getOptionValue('google_font_subset'), 1);
		}
		
		$font_subset_str = 'latin-ext';
		if ( !empty($google_font_subset_array) && $google_font_subset_array !== '' ) {
			$font_subset_str = implode(',', $google_font_subset_array);
		}
		
		//default fonts
		$default_font_family = array(
			'Montserrat'
		);
		
		$modified_default_font_family = array();
		foreach ( $default_font_family as $default_font ) {
			$modified_default_font_family[] = $default_font . ':' . $font_weight_str;
		}
		
		$default_font_string = implode('|', $modified_default_font_family);
		
		//define available font options array
		$fonts_array = array();
		foreach ( $available_font_options as $font_option ) {
			//is font set and not set to default and not empty?
			$font_option_value = aoki_qodef_options()->getOptionValue($font_option);
			
			if ( aoki_qodef_is_font_option_valid($font_option_value) && !aoki_qodef_is_native_font($font_option_value) ) {
				$font_option_string = $font_option_value . ':' . $font_weight_str;
				
				if ( !in_array(str_replace('+', ' ', $font_option_value), $default_font_family) && !in_array($font_option_string, $fonts_array) ) {
					$fonts_array[] = $font_option_string;
				}
			}
		}
		
		$fonts_array = array_diff($fonts_array, array('-1:' . $font_weight_str));
		$google_fonts_string = implode('|', $fonts_array);
		
		$protocol = is_ssl() ? 'https:' : 'http:';
		
		//is google font option checked anywhere in theme?
		if ( count($fonts_array) > 0 ) {
			
			//include all checked fonts
			$fonts_full_list = $default_font_string . '|' . str_replace('+', ' ', $google_fonts_string);
			$fonts_full_list_args = array(
				'family' => urlencode($fonts_full_list),
				'subset' => urlencode($font_subset_str),
			);
			
			$aoki_qodef_fonts = add_query_arg($fonts_full_list_args, $protocol . '//fonts.googleapis.com/css');
			wp_enqueue_style('aoki-qodef-google-fonts', esc_url_raw($aoki_qodef_fonts), array(), '1.0.0');
			
		} else {
			//include default google font that theme is using
			$default_fonts_args = array(
				'family' => urlencode($default_font_string),
				'subset' => urlencode($font_subset_str),
			);
			$aoki_qodef_fonts = add_query_arg($default_fonts_args, $protocol . '//fonts.googleapis.com/css');
			wp_enqueue_style('aoki-qodef-google-fonts', esc_url_raw($aoki_qodef_fonts), array(), '1.0.0');
		}
	}
	
	add_action('wp_enqueue_scripts', 'aoki_qodef_google_fonts_styles');
}

if ( !function_exists('aoki_qodef_scripts') ) {
	/**
	 * Function that includes all necessary scripts
	 */
	function aoki_qodef_scripts() {
		global $wp_scripts;
		
		//init theme core scripts
		wp_enqueue_script('jquery-ui-core');
		wp_enqueue_script('jquery-ui-tabs');
		wp_enqueue_script('jquery-ui-accordion');
		wp_enqueue_script('wp-mediaelement');
		
		// 3rd party JavaScripts that we used in our theme
		wp_enqueue_script('appear', QODE_ASSETS_ROOT . '/js/modules/plugins/jquery.appear.js', array('jquery'), false, true);
		wp_enqueue_script('modernizr', QODE_ASSETS_ROOT . '/js/modules/plugins/modernizr.min.js', array('jquery'), false, true);
		wp_enqueue_script('hoverIntent', QODE_ASSETS_ROOT . '/js/modules/plugins/jquery.hoverIntent.min.js', array('jquery'), false, true);
		wp_enqueue_script('jquery-plugin', QODE_ASSETS_ROOT . '/js/modules/plugins/jquery.plugin.js', array('jquery'), false, true);
		wp_enqueue_script('owl-carousel', QODE_ASSETS_ROOT . '/js/modules/plugins/owl.carousel.min.js', array('jquery'), false, true);
		wp_enqueue_script('waypoints', QODE_ASSETS_ROOT . '/js/modules/plugins/jquery.waypoints.min.js', array('jquery'), false, true);
		wp_enqueue_script('chart', QODE_ASSETS_ROOT . '/js/modules/plugins/Chart.min.js', array('jquery'), false, true);
		wp_enqueue_script('fluidvids', QODE_ASSETS_ROOT . '/js/modules/plugins/fluidvids.min.js', array('jquery'), false, true);
		wp_enqueue_script('prettyphoto', QODE_ASSETS_ROOT . '/js/modules/plugins/jquery.prettyPhoto.js', array('jquery'), false, true);
		wp_enqueue_script('perfect-scrollbar', QODE_ASSETS_ROOT . '/js/modules/plugins/perfect-scrollbar.jquery.min.js', array('jquery'), false, true);
		wp_enqueue_script('ScrollToPlugin', QODE_ASSETS_ROOT . '/js/modules/plugins/ScrollToPlugin.min.js', array('jquery'), false, true);
		wp_enqueue_script('parallax', QODE_ASSETS_ROOT . '/js/modules/plugins/parallax.min.js', array('jquery'), false, true);
		wp_enqueue_script('waitforimages', QODE_ASSETS_ROOT . '/js/modules/plugins/jquery.waitforimages.js', array('jquery'), false, true);
		wp_enqueue_script('jquery-easing-1.3', QODE_ASSETS_ROOT . '/js/modules/plugins/jquery.easing.1.3.js', array('jquery'), false, true);
		wp_enqueue_script('isotope', QODE_ASSETS_ROOT . '/js/modules/plugins/isotope.pkgd.min.js', array('jquery'), false, true);
		wp_enqueue_script('packery', QODE_ASSETS_ROOT . '/js/modules/plugins/packery-mode.pkgd.min.js', array('jquery'), false, true);
		wp_enqueue_script('slick-slider', QODE_ASSETS_ROOT . '/js/modules/plugins/slick.min.js', array('jquery'), false, true);
		wp_enqueue_script('parallax-scroll', QODE_ASSETS_ROOT . '/js/modules/plugins/jquery.parallax-scroll.js', array('jquery'), false, true);
		wp_enqueue_script('mousewheel', QODE_ASSETS_ROOT . '/js/modules/plugins/jquery.mousewheel.min.js', array('jquery'), false, true);
		
		do_action('aoki_qodef_enqueue_third_party_scripts');
		
		if ( aoki_qodef_is_woocommerce_installed() ) {
			wp_enqueue_script('select2');
		}
		
		if ( aoki_qodef_is_page_smooth_scroll_enabled() ) {
			wp_enqueue_script('tweenLite', QODE_ASSETS_ROOT . '/js/modules/plugins/TweenLite.min.js', array('jquery'), false, true);
			wp_enqueue_script('smoothPageScroll', QODE_ASSETS_ROOT . '/js/modules/plugins/smoothPageScroll.js', array('jquery'), false, true);
		}
		
		//include google map api script
		$google_maps_api_key = aoki_qodef_options()->getOptionValue('google_maps_api_key');
		$google_maps_extensions = '';
		$google_maps_extensions_array = apply_filters('aoki_qodef_google_maps_extensions_array', array());
		if ( !empty($google_maps_extensions_array) ) {
			$google_maps_extensions .= '&libraries=';
			$google_maps_extensions .= implode(',', $google_maps_extensions_array);
		}
		if ( !empty($google_maps_api_key) ) {
			wp_enqueue_script('aoki_qodef_google_map_api', '//maps.googleapis.com/maps/api/js?key=' . esc_attr($google_maps_api_key) . $google_maps_extensions, array(), false, true);
		}
		
		wp_enqueue_script('aoki-qodef-modules', QODE_ASSETS_ROOT . '/js/modules.min.js', array('jquery'), false, true);
		
		//include comment reply script
		$wp_scripts->add_data('comment-reply', 'group', 1);
		if ( is_singular() && comments_open() && get_option('thread_comments') ) {
			wp_enqueue_script('comment-reply');
		}
	}
	
	add_action('wp_enqueue_scripts', 'aoki_qodef_scripts');
}

if ( !function_exists('aoki_qodef_theme_setup') ) {
	/**
	 * Function that adds various features to theme. Also defines image sizes that are used in a theme
	 */
	function aoki_qodef_theme_setup() {
		//add support for feed links
		add_theme_support('automatic-feed-links');
		
		//add support for post formats
		add_theme_support('post-formats', array('gallery', 'link', 'quote', 'video', 'audio'));
		
		//add theme support for post thumbnails
		add_theme_support('post-thumbnails');
		
		//add theme support for title tag
		add_theme_support('title-tag');
		
		//add theme support for editor style
		add_editor_style('framework/admin/assets/css/editor-style.css');
		
		//defined content width variable
		$GLOBALS['content_width'] = apply_filters('aoki_qodef_set_content_width', 1100);
		
		//define thumbnail sizes
		add_image_size('aoki_qodef_square', 550, 550, true);
		add_image_size('aoki_qodef_landscape', 1100, 550, true);
		add_image_size('aoki_qodef_portrait', 550, 1100, true);
		add_image_size('aoki_qodef_huge', 1100, 1100, true);
		
		load_theme_textdomain('aoki', get_template_directory() . '/languages');
	}
	
	add_action('after_setup_theme', 'aoki_qodef_theme_setup');
}

if ( ! function_exists( 'aoki_qodef_enqueue_editor_customizer_styles' ) ) {
	/**
	 * Enqueue supplemental block editor styles
	 */
	function aoki_qodef_enqueue_editor_customizer_styles() {
		wp_enqueue_style( 'aoki-qodef-style-modules-admin-styles', QODE_FRAMEWORK_ADMIN_ASSETS_ROOT . '/css/qodef-modules-admin.css' );
		wp_enqueue_style( 'aoki-qodef-style-handle-editor-customizer-styles', QODE_FRAMEWORK_ADMIN_ASSETS_ROOT . '/css/editor-customizer-style.css' );
	}
	
	// add google font
	add_action( 'enqueue_block_editor_assets', 'aoki_qodef_google_fonts_styles' );
	// add action
	add_action( 'enqueue_block_editor_assets', 'aoki_qodef_enqueue_editor_customizer_styles' );
}

if ( !function_exists('aoki_qodef_is_responsive_on') ) {
	/**
	 * Checks whether responsive mode is enabled in theme options
	 * @return bool
	 */
	function aoki_qodef_is_responsive_on() {
		return aoki_qodef_options()->getOptionValue('responsiveness') !== 'no';
	}
}

if ( !function_exists('aoki_qodef_rgba_color') ) {
	/**
	 * Function that generates rgba part of css color property
	 *
	 * @param $color string hex color
	 * @param $transparency float transparency value between 0 and 1
	 *
	 * @return string generated rgba string
	 */
	function aoki_qodef_rgba_color($color, $transparency) {
		if ( $color !== '' && $transparency !== '' ) {
			$rgba_color = '';
			
			$rgb_color_array = aoki_qodef_hex2rgb($color);
			$rgba_color .= 'rgba(' . implode(', ', $rgb_color_array) . ', ' . $transparency . ')';
			
			return $rgba_color;
		}
	}
}

if ( !function_exists('aoki_qodef_header_meta') ) {
	/**
	 * Function that echoes meta data if our seo is enabled
	 */
	function aoki_qodef_header_meta() { ?>

        <meta charset="<?php bloginfo('charset'); ?>"/>
        <link rel="profile" href="http://gmpg.org/xfn/11"/>
		<?php if ( is_singular() && pings_open(get_queried_object()) ) : ?>
            <link rel="pingback" href="<?php bloginfo('pingback_url'); ?>">
		<?php endif; ?>
	
	<?php }
	
	add_action('aoki_qodef_header_meta', 'aoki_qodef_header_meta');
}

if ( !function_exists('aoki_qodef_user_scalable_meta') ) {
	/**
	 * Function that outputs user scalable meta if responsiveness is turned on
	 * Hooked to aoki_qodef_header_meta action
	 */
	function aoki_qodef_user_scalable_meta() {
		//is responsiveness option is chosen?
		if ( aoki_qodef_is_responsive_on() ) { ?>
            <meta name="viewport" content="width=device-width,initial-scale=1,user-scalable=yes">
		<?php } else { ?>
            <meta name="viewport" content="width=1200,user-scalable=yes">
		<?php }
	}
	
	add_action('aoki_qodef_header_meta', 'aoki_qodef_user_scalable_meta');
}

if ( !function_exists('aoki_qodef_smooth_page_transitions') ) {
	/**
	 * Function that outputs smooth page transitions html if smooth page transitions functionality is turned on
	 * Hooked to aoki_qodef_after_body_tag action
	 */
	function aoki_qodef_smooth_page_transitions() {
		$id = aoki_qodef_get_page_id();
		
		if ( aoki_qodef_get_meta_field_intersect('smooth_page_transitions', $id) === 'yes' &&
			 aoki_qodef_get_meta_field_intersect('page_transition_preloader', $id) === 'yes'
		) { ?>
            <div class="qodef-smooth-transition-loader qodef-mimic-ajax">
                <div class="qodef-st-loader">
                    <div class="qodef-st-loader1">
						<?php aoki_qodef_loading_spinners(); ?>
                    </div>
                </div>
            </div>
		<?php }
	}
	
	add_action('aoki_qodef_after_body_tag', 'aoki_qodef_smooth_page_transitions', 10);
}

if ( !function_exists('aoki_qodef_back_to_top_button') ) {
	/**
	 * Function that outputs back to top button html if back to top functionality is turned on
	 * Hooked to aoki_qodef_after_wrapper_inner action
	 */
	function aoki_qodef_back_to_top_button() {
		if ( aoki_qodef_options()->getOptionValue('show_back_button') == 'yes' ) { ?>
            <a id='qodef-back-to-top' href='#'>
                <span class="qodef-icon-stack">
                     <?php aoki_qodef_icon_collections()->getBackToTopIcon('font_awesome'); ?>
					<span class="qodef-btt-text-holder">
						<span class="qodef-btt-text"><?php echo esc_html__('Back To Top', 'aoki'); ?></span>
					</span>
                </span>
            </a>
		<?php }
	}
	
	add_action('aoki_qodef_after_wrapper_inner', 'aoki_qodef_back_to_top_button', 30);
}

if ( !function_exists('aoki_qodef_get_page_id') ) {
	/**
	 * Function that returns current page / post id.
	 * Checks if current page is woocommerce page and returns that id if it is.
	 * Checks if current page is any archive page (category, tag, date, author etc.) and returns -1 because that isn't
	 * page that is created in WP admin.
	 *
	 * @return int
	 *
	 * @version 0.1
	 *
	 * @see aoki_qodef_is_woocommerce_installed()
	 * @see aoki_qodef_is_woocommerce_shop()
	 */
	function aoki_qodef_get_page_id() {
		if ( aoki_qodef_is_woocommerce_installed() && aoki_qodef_is_woocommerce_shop() ) {
			return aoki_qodef_get_woo_shop_page_id();
		}
		
		if ( aoki_qodef_is_default_wp_template() ) {
			return -1;
		}
		
		return get_queried_object_id();
	}
}

if ( !function_exists('aoki_qodef_get_multisite_blog_id') ) {
	/**
	 * Check is multisite and return blog id
	 *
	 * @return int
	 */
	function aoki_qodef_get_multisite_blog_id() {
		if ( is_multisite() ) {
			return get_blog_details()->blog_id;
		}
	}
}

if ( !function_exists('aoki_qodef_is_default_wp_template') ) {
	/**
	 * Function that checks if current page archive page, search, 404 or default home blog page
	 * @return bool
	 *
	 * @see is_archive()
	 * @see is_search()
	 * @see is_404()
	 * @see is_front_page()
	 * @see is_home()
	 */
	function aoki_qodef_is_default_wp_template() {
		return is_archive() || is_search() || is_404() || (is_front_page() && is_home());
	}
}

if ( !function_exists('aoki_qodef_has_shortcode') ) {
	/**
	 * Function that checks whether shortcode exists on current page / post
	 *
	 * @param string shortcode to find
	 * @param string content to check. If isn't passed current post content will be used
	 *
	 * @return bool whether content has shortcode or not
	 */
	function aoki_qodef_has_shortcode($shortcode, $content = '') {
		$has_shortcode = false;
		
		if ( $shortcode ) {
			//if content variable isn't past
			if ( $content == '' ) {
				//take content from current post
				$page_id = aoki_qodef_get_page_id();
				if ( !empty($page_id) ) {
					$current_post = get_post($page_id);
					
					if ( is_object($current_post) && property_exists($current_post, 'post_content') ) {
						$content = $current_post->post_content;
					}
				}
			}
			
			//does content has shortcode added?
			if ( stripos($content, '[' . $shortcode) !== false ) {
				$has_shortcode = true;
			}
		}
		
		return $has_shortcode;
	}
}

if ( !function_exists('aoki_qodef_get_unique_page_class') ) {
	/**
	 * Returns unique page class based on post type and page id
	 *
	 * $params int $id is page id
	 * $params bool $allowSingleProductOption
	 * @return string
	 */
	function aoki_qodef_get_unique_page_class($id, $allowSingleProductOption = false) {
		$page_class = '';
		
		if ( aoki_qodef_is_woocommerce_installed() && $allowSingleProductOption ) {
			
			if ( is_product() ) {
				$id = get_the_ID();
			}
		}
		
		if ( is_single() ) {
			$page_class = '.postid-' . $id;
		} elseif ( is_home() ) {
			$page_class .= '.home';
		} elseif ( is_archive() || $id === aoki_qodef_get_woo_shop_page_id() ) {
			$page_class .= '.archive';
		} elseif ( is_search() ) {
			$page_class .= '.search';
		} elseif ( is_404() ) {
			$page_class .= '.error404';
		} else {
			$page_class .= '.page-id-' . $id;
		}
		
		return $page_class;
	}
}

if ( !function_exists('aoki_qodef_page_custom_style') ) {
	/**
	 * Function that print custom page style
	 */
	function aoki_qodef_page_custom_style() {
		$style = apply_filters('aoki_qodef_add_page_custom_style', $style = '');
		
		if ( $style !== '' ) {
			
			if ( aoki_qodef_is_woocommerce_installed() && aoki_qodef_load_woo_assets() ) {
				wp_add_inline_style('aoki-qodef-woo', $style);
			} else {
				wp_add_inline_style('aoki-qodef-modules', $style);
			}
		}
	}
	
	add_action('wp_enqueue_scripts', 'aoki_qodef_page_custom_style');
}

if ( !function_exists('aoki_qodef_container_style') ) {
	/**
	 * Function that return container style
	 */
	function aoki_qodef_container_style($style) {
		$page_id = aoki_qodef_get_page_id();
		$class_prefix = aoki_qodef_get_unique_page_class($page_id, true);
		
		$container_selector = array(
			$class_prefix . ' .qodef-content .qodef-content-inner > .qodef-container',
			$class_prefix . ' .qodef-content .qodef-content-inner > .qodef-full-width'
		);
		
		$container_class = array();
		$page_backgorund_color = get_post_meta($page_id, 'qodef_page_background_color_meta', true);
		
		if ( $page_backgorund_color ) {
			$container_class['background-color'] = $page_backgorund_color;
		}
		
		$current_style = aoki_qodef_dynamic_css($container_selector, $container_class);
		$current_style = $current_style . $style;
		
		return $current_style;
	}
	
	add_filter('aoki_qodef_add_page_custom_style', 'aoki_qodef_container_style');
}

if ( !function_exists('aoki_qodef_content_padding_top') ) {
	/**
	 * Function that return padding for content
	 */
	function aoki_qodef_content_padding_top($style) {
		$page_id = aoki_qodef_get_page_id();
		$class_prefix = aoki_qodef_get_unique_page_class($page_id, true);
		
		$current_style = '';
		
		$content_selector = array(
			$class_prefix . ' .qodef-content .qodef-content-inner > .qodef-container > .qodef-container-inner',
			$class_prefix . ' .qodef-content .qodef-content-inner > .qodef-full-width > .qodef-full-width-inner',
		);
		
		$content_class = array();
		
		$page_padding_top = get_post_meta($page_id, 'qodef_page_content_top_padding', true);
		
		if ( $page_padding_top !== '' ) {
			if ( get_post_meta($page_id, 'qodef_page_content_top_padding_mobile', true) == 'yes' ) {
				$content_class['padding-top'] = aoki_qodef_filter_px($page_padding_top) . 'px !important';
			} else {
				$content_class['padding-top'] = aoki_qodef_filter_px($page_padding_top) . 'px';
			}
			$current_style .= aoki_qodef_dynamic_css($content_selector, $content_class);
		}
		
		$current_style = $current_style . $style;
		
		return $current_style;
	}
	
	add_filter('aoki_qodef_add_page_custom_style', 'aoki_qodef_content_padding_top');
}

if ( !function_exists('aoki_qodef_print_custom_js') ) {
	/**
	 * Prints out custom css from theme options
	 */
	function aoki_qodef_print_custom_js() {
		$custom_js = aoki_qodef_options()->getOptionValue('custom_js');
		
		if ( !empty($custom_js) ) {
			wp_add_inline_script('aoki-qodef-modules', $custom_js);
		}
	}
	
	add_action('wp_enqueue_scripts', 'aoki_qodef_print_custom_js');
}

if ( !function_exists('aoki_qodef_get_global_variables') ) {
	/**
	 * Function that generates global variables and put them in array so they could be used in the theme
	 */
	function aoki_qodef_get_global_variables() {
		$global_variables = array();
		
		$global_variables['qodefAddForAdminBar'] = is_admin_bar_showing() ? 32 : 0;
		$global_variables['qodefElementAppearAmount'] = -100;
		$global_variables['qodefAjaxUrl'] = esc_url(admin_url('admin-ajax.php'));
		
		$global_variables = apply_filters('aoki_qodef_js_global_variables', $global_variables);
		
		wp_localize_script('aoki-qodef-modules', 'qodefGlobalVars', array(
			'vars' => $global_variables
		));
	}
	
	add_action('wp_enqueue_scripts', 'aoki_qodef_get_global_variables');
}

if ( !function_exists('aoki_qodef_per_page_js_variables') ) {
	/**
	 * Outputs global JS variable that holds page settings
	 */
	function aoki_qodef_per_page_js_variables() {
		$per_page_js_vars = apply_filters('aoki_qodef_per_page_js_vars', array());
		
		wp_localize_script('aoki-qodef-modules', 'qodefPerPageVars', array(
			'vars' => $per_page_js_vars
		));
	}
	
	add_action('wp_enqueue_scripts', 'aoki_qodef_per_page_js_variables');
}

if ( !function_exists('aoki_qodef_content_elem_style_attr') ) {
	/**
	 * Defines filter for adding custom styles to content HTML element
	 */
	function aoki_qodef_content_elem_style_attr() {
		$styles = apply_filters('aoki_qodef_content_elem_style_attr', array());
		
		aoki_qodef_inline_style($styles);
	}
}

if ( !function_exists('aoki_qodef_core_plugin_installed') ) {
	/**
	 * Function that checks if Qode Core plugin installed
	 * @return bool
	 */
	function aoki_qodef_core_plugin_installed() {
		return defined('QODE_CORE_VERSION');
	}
}

if ( !function_exists('aoki_qodef_is_woocommerce_installed') ) {
	/**
	 * Function that checks if Woocommerce plugin installed
	 * @return bool
	 */
	function aoki_qodef_is_woocommerce_installed() {
		return function_exists('is_woocommerce');
	}
}

if ( !function_exists('aoki_qodef_visual_composer_installed') ) {
	/**
	 * Function that checks if Visual Composer plugin installed
	 * @return bool
	 */
	function aoki_qodef_visual_composer_installed() {
		return class_exists('WPBakeryVisualComposerAbstract');
	}
}

if ( !function_exists('aoki_qodef_revolution_slider_installed') ) {
	/**
	 * Function that checks if Revolution Slider plugin installed
	 * @return bool
	 */
	function aoki_qodef_revolution_slider_installed() {
		return class_exists('RevSliderFront');
	}
}

if ( !function_exists('aoki_qodef_contact_form_7_installed') ) {
	/**
	 * Function that checks if Contact Form 7 plugin installed
	 * @return bool
	 */
	function aoki_qodef_contact_form_7_installed() {
		return defined('WPCF7_VERSION');
	}
}

if ( !function_exists('aoki_qodef_is_wpml_installed') ) {
	/**
	 * Function that checks if WPML plugin installed
	 * @return bool
	 */
	function aoki_qodef_is_wpml_installed() {
		return defined('ICL_SITEPRESS_VERSION');
	}
}

if ( !function_exists('aoki_qodef_generate_first_main_color_per_page') ) {
	/**
	 * Function that checks first main color in page options and generate css if color is set
	 */
	function aoki_qodef_generate_first_main_color_per_page($style) {
		$id = aoki_qodef_get_page_id();
		$first_color = aoki_qodef_get_meta_field_intersect('first_color', $id);
		if ( $first_color !== '' ) {
			
			extract(aoki_qodef_generate_first_color_selectors());
			
			$style .= aoki_qodef_dynamic_css($color_selector, array('color' => $first_color));
			$style .= aoki_qodef_dynamic_css($color_important_selector, array('color' => $first_color . ' !important'));
			$style .= aoki_qodef_dynamic_css('::selection', array('background' => $first_color));
			$style .= aoki_qodef_dynamic_css('::-moz-selection', array('background' => $first_color));
			$style .= aoki_qodef_dynamic_css($background_color_selector, array('background-color' => $first_color));
			$style .= aoki_qodef_dynamic_css($border_color_selector, array('border-color' => $first_color));
			$style .= aoki_qodef_dynamic_css($border_top_color_selector, array('border-top-color' => $first_color));
			$style .= aoki_qodef_dynamic_css($border_bottom_color_selector, array('border-bottom-color' => $first_color));
			$style .= aoki_qodef_dynamic_css($border_left_color_selector, array('border-left-color' => $first_color));
			$style .= aoki_qodef_dynamic_css($border_color_important_selector, array('border-color' => $first_color . ' !important'));
		}
		return $style;
	}
	
	
	add_filter('aoki_qodef_add_page_custom_style', 'aoki_qodef_generate_first_main_color_per_page');
}

if ( !function_exists('aoki_qodef_generate_first_color_selectors') ) {
	/**
	 * Function generate arrays of selectors for first color option
	 */
	function aoki_qodef_generate_first_color_selectors() {
		
		$return_array = array();
		//generate color selector array
		$return_array['color_selector'] = array(
			'a:hover',
			'p a:hover',
			'.qodef-comment-holder .qodef-comment-text #cancel-comment-reply-link',
			'.qodef-owl-slider .owl-nav .owl-next:hover',
			'.qodef-owl-slider .owl-nav .owl-prev:hover',
			'#qodef-back-to-top>span',
			'footer .widget ul li a:hover',
			'footer .widget #wp-calendar td a:hover',
			'footer .widget #wp-calendar th a:hover',
			'footer .widget.widget_search .input-holder button:hover',
			'footer .widget.widget_tag_cloud a:hover',
			'footer .widget.qodef-blog-list-widget .qodef-blog-list-holder.qodef-bl-simple .qodef-post-info-date a:hover',
			'footer .widget.qodef-blog-list-widget .qodef-blog-list-holder.qodef-bl-simple .qodef-post-title a:hover',
			'.qodef-side-menu .widget ul li a:hover',
			'.qodef-side-menu .widget #wp-calendar td a:hover',
			'.qodef-side-menu .widget #wp-calendar th a:hover',
			'.qodef-side-menu .widget.widget_search .input-holder button:hover',
			'.qodef-side-menu .widget.widget_tag_cloud a:hover',
			'.qodef-side-menu .widget.qodef-blog-list-widget .qodef-blog-list-holder.qodef-bl-minimal .qodef-post-info-date a:hover',
			'.qodef-side-menu .widget.qodef-blog-list-widget .qodef-blog-list-holder.qodef-bl-minimal .qodef-post-title a:hover',
			'.widget.widget_qodef_twitter_widget .qodef-twitter-widget.qodef-twitter-slider li .qodef-twitter-icon i',
			'.widget.widget_qodef_twitter_widget .qodef-twitter-widget.qodef-twitter-slider li .qodef-tweet-text a',
			'.widget.widget_qodef_twitter_widget .qodef-twitter-widget.qodef-twitter-slider li .qodef-tweet-text span',
			'.qodef-blog-holder article.sticky .qodef-post-title a',
			'.qodef-blog-holder article .qodef-post-info-top>div a:hover',
			'.qodef-blog-holder article.format-link .qodef-post-mark .qodef-link-mark',
			'.qodef-blog-holder article.format-quote .qodef-post-mark .qodef-quote-mark',
			'.qodef-blog-holder.qodef-blog-chequered article .qodef-post-info-bottom>div a:hover',
			'.qodef-blog-holder.qodef-blog-chequered article .qodef-post-info-bottom>div.qodef-post-info-category a',
			'.qodef-blog-holder.qodef-blog-chequered article .qodef-post-title a:hover',
			'.qodef-blog-holder.qodef-blog-full-width-photo article .qodef-post-info-section-top .qodef-post-info-date a:hover',
			'.qodef-blog-holder.qodef-blog-full-width-photo article .qodef-post-info-section-top .qodef-post-info-category a',
			'.qodef-blog-holder.qodef-blog-full-width-photo article .qodef-post-info-section-left .qodef-post-info>* a:hover',
			'.qodef-blog-holder.qodef-blog-full-width-photo article .qodef-post-info-section-left .qodef-post-info-author a:hover',
			'.qodef-blog-holder.qodef-blog-standard article .qodef-post-info-top>div.qodef-post-info-category a',
			'.qodef-author-description .qodef-author-description-text-holder .qodef-author-tag',
			'.qodef-author-description .qodef-author-description-text-holder .qodef-author-name a:hover',
			'.qodef-bl-standard-pagination ul li.qodef-bl-pag-active a',
			'.qodef-blog-single-navigation .qodef-blog-single-next:hover',
			'.qodef-blog-single-navigation .qodef-blog-single-prev:hover',
			'.qodef-blog-holder.qodef-blog-single article .qodef-post-info-top>div.qodef-post-info-category a',
			'.qodef-blog-list-holder .qodef-bli-info>div.qodef-post-info-category a',
			'.qodef-header-bottom nav.qodef-fullscreen-menu ul li ul li.current-menu-ancestor>a',
			'.qodef-header-bottom nav.qodef-fullscreen-menu ul li ul li.current-menu-item>a',
			'nav.qodef-fullscreen-menu ul li ul li.current-menu-ancestor>a',
			'nav.qodef-fullscreen-menu ul li ul li.current-menu-item>a',
			'.qodef-header-vertical-sliding nav.qodef-fullscreen-menu ul li ul li.current-menu-ancestor>a',
			'.qodef-header-vertical-sliding nav.qodef-fullscreen-menu ul li ul li.current-menu-item>a',
			'.qodef-mobile-header .qodef-mobile-menu-opener.qodef-mobile-menu-opened a',
			'.qodef-mobile-header .qodef-mobile-nav .qodef-grid>ul>li.qodef-active-item>a',
			'.qodef-mobile-header .qodef-mobile-nav .qodef-grid>ul>li.qodef-active-item>h6',
			'.qodef-mobile-header .qodef-mobile-nav ul li a:hover',
			'.qodef-mobile-header .qodef-mobile-nav ul li h6:hover',
			'.qodef-mobile-header .qodef-mobile-nav ul ul li.current-menu-ancestor>a',
			'.qodef-mobile-header .qodef-mobile-nav ul ul li.current-menu-ancestor>h6',
			'.qodef-mobile-header .qodef-mobile-nav ul ul li.current-menu-item>a',
			'.qodef-mobile-header .qodef-mobile-nav ul ul li.current-menu-item>h6',
			'.qodef-search-page-holder article.sticky .qodef-post-title a',
			'.qodef-horizontally-scrolling-portfolio-list-holder article .qodef-hspl-text-holder .qodef-hspl-text .qodef-pli-category-holder a.qodef-pli-category',
			'.qodef-ips #qodef-ips-intro .qodef-ips-intro-text .qodef-dot',
			'.qodef-pl-filter-holder ul li.qodef-pl-current span',
			'.qodef-pl-filter-holder ul li:hover span',
			'.qodef-pl-standard-pagination ul li.qodef-pl-pag-active a',
			'.qodef-portfolio-pair-holder .qodef-ppi .qodef-ppi-inner .qodef-ppi-text-wrapper .qodef-ppi-category a',
			'.qodef-portfolio-list-holder.qodef-pl-gallery-overlay-shader article .qodef-pli-text .qodef-pli-category-holder a:hover',
			'.qodef-portfolio-list-holder.qodef-pl-gallery-overlay-shader-top article .qodef-pli-text .qodef-pli-category-holder a:hover',
			'.qodef-team-modal-holder .qodef-team-position-holder .qodef-team-position',
			'.qodef-team-single-holder .qodef-position',
			'.qodef-testimonials-holder.qodef-testimonials-standard .qodef-testimonials-author-job',
			'.qodef-testimonials-holder.qodef-testimonials-standard.qodef-testimonials-light .owl-nav .owl-next:hover',
			'.qodef-testimonials-holder.qodef-testimonials-standard.qodef-testimonials-light .owl-nav .owl-prev:hover',
			'.qodef-accordion-holder .qodef-accordion-title .qodef-additional-tag',
			'.qodef-banner-holder .qodef-banner-link-text .qodef-banner-link-hover span',
			'.qodef-btn.qodef-btn-simple',
			'.qodef-btn.qodef-btn-outline',
			'.qodef-section-title-holder .qodef-st-title .qodef-st-dot',
			'.qodef-social-share-holder.qodef-dropdown .qodef-social-share-dropdown-opener:hover',
			'.qodef-twitter-list-holder .qodef-twitter-icon',
			'.qodef-twitter-list-holder .qodef-tweet-text a:hover',
			'.qodef-twitter-list-holder .qodef-twitter-profile a:hover'
		);
		
		$woo_color_selector = array();
		if ( aoki_qodef_is_woocommerce_installed() ) {
			$woo_color_selector = array(
				'.qodef-woo-single-page .qodef-single-product-summary .product_meta>span a:hover',
				'.qodef-shopping-cart-dropdown .qodef-item-info-holder .qodef-product-title a:hover',
				'.qodef-shopping-cart-dropdown .qodef-item-info-holder .amount',
				'.qodef-shopping-cart-dropdown .qodef-item-info-holder .qodef-quantity',
				'.widget.woocommerce.widget_layered_nav ul li.chosen a'
			);
		}
		
		$return_array['color_selector'] = array_merge($return_array['color_selector'], $woo_color_selector);
		
		
		//generate color important selector array
		$return_array['color_important_selector'] = array(
			'.qodef-ips.qodef-ips-light .qodef-ips-item-content.active .qodef-ips-item-link'
		);
		
		//generate background color selectors array
		$return_array['background_color_selector'] = array(
			'.qodef-st-loader .pulse',
			'.qodef-st-loader .qodef-double-bounce .qodef-double-bounce1',
			'.qodef-st-loader .cube',
			'.qodef-st-loader .rotating_cubes .cube1',
			'.qodef-st-loader .rotating_cubes .cube2',
			'.qodef-st-loader .stripes>div',
			'.qodef-st-loader .wave>div',
			'.qodef-st-loader .two_rotating_circles .dot1',
			'.qodef-st-loader .two_rotating_circles .dot2',
			'.qodef-st-loader .five_rotating_circles .container1>div',
			'.qodef-st-loader .five_rotating_circles .container2>div',
			'.qodef-st-loader .five_rotating_circles .container3>div',
			'.qodef-st-loader .atom .ball-1:before',
			'.qodef-st-loader .atom .ball-2:before',
			'.qodef-st-loader .atom .ball-3:before',
			'.qodef-st-loader .atom .ball-4:before',
			'.qodef-st-loader .clock .ball:before',
			'.qodef-st-loader .mitosis .ball',
			'.qodef-st-loader .lines .line1',
			'.qodef-st-loader .lines .line2',
			'.qodef-st-loader .lines .line3',
			'.qodef-st-loader .lines .line4',
			'.qodef-st-loader .fussion .ball',
			'.qodef-st-loader .fussion .ball-1',
			'.qodef-st-loader .fussion .ball-2',
			'.qodef-st-loader .fussion .ball-3',
			'.qodef-st-loader .fussion .ball-4',
			'.qodef-st-loader .wave_circles .ball',
			'.qodef-st-loader .pulse_circles .ball',
			'#submit_comment:hover',
			'.post-password-form input[type=submit]:hover',
			'.qodef-blog-holder.qodef-blog-full-width-photo article.format-link .qodef-post-heading',
			'.qodef-blog-holder.qodef-blog-standard article.format-link .qodef-post-text',
			'.qodef-blog-holder.qodef-blog-single article.format-link .qodef-post-text',
			'.qodef-blog-list-holder .qodef-bl-item.format-link .qodef-bli-inner',
			'.qodef-ips .qodef-ips-item-link .qodef-box-shadow',
			'.qodef-team.info-hover .qodef-team-info-tb',
			'.qodef-accordion-holder.qodef-ac-boxed .qodef-accordion-title.ui-state-active',
			'.qodef-accordion-holder.qodef-ac-boxed .qodef-accordion-title.ui-state-hover',
			'.qodef-icon-shortcode.qodef-circle',
			'.qodef-icon-shortcode.qodef-dropcaps.qodef-circle',
			'.qodef-icon-shortcode.qodef-square',
			'.qodef-price-table.qodef-pl-featured .qodef-pt-button a',
			'.qodef-price-table .qodef-pt-inner ul li.qodef-pt-prices .qodef-pt-separator',
			'.qodef-progress-bar .qodef-pb-content-holder .qodef-pb-content',
			'.qodef-video-button-holder .qodef-video-button-play-holder'
		);
		
		$woo_background_color_selector = array();
		if ( aoki_qodef_is_woocommerce_installed() ) {
			$woo_background_color_selector = array(
				'.qodef-pl-holder .qodef-pli-inner .qodef-pli-text-inner .qodef-pli-add-to-cart.qodef-default-skin .added_to_cart:hover',
				'.qodef-pl-holder .qodef-pli-inner .qodef-pli-text-inner .qodef-pli-add-to-cart.qodef-default-skin .button:hover',
				'.qodef-pl-holder .qodef-pli-inner .qodef-pli-text-inner .qodef-pli-add-to-cart.qodef-light-skin .added_to_cart:hover',
				'.qodef-pl-holder .qodef-pli-inner .qodef-pli-text-inner .qodef-pli-add-to-cart.qodef-light-skin .button:hover',
				'.qodef-pl-holder .qodef-pli-inner .qodef-pli-text-inner .qodef-pli-add-to-cart.qodef-dark-skin .added_to_cart:hover',
				'.qodef-pl-holder .qodef-pli-inner .qodef-pli-text-inner .qodef-pli-add-to-cart.qodef-dark-skin .button:hover'
			);
		}
		
		$return_array['background_color_selector'] = array_merge($return_array['background_color_selector'], $woo_background_color_selector);
		
		//generate border color selectors array
		$return_array['border_color_selector'] = array(
			'.qodef-st-loader .pulse_circles .ball',
			'#qodef-back-to-top>span',
			'#qodef-back-to-top>span:hover',
			'.qodef-btn.qodef-btn-simple',
			'.qodef-btn.qodef-btn-outline',
			'.qodef-video-button-holder.qodef-has-border .qodef-video-button-image'
		);
		
		$return_array['border_top_color_selector'] = array();
		
		$return_array['border_bottom_color_selector'] = array(
			'.qodef-separator'
		);
		
		$return_array['border_left_color_selector'] = array(
			'.qodef-separator'
		);
		
		$return_array['border_color_important_selector'] = array(
			'.qodef-btn.qodef-btn-outline:not(.qodef-btn-custom-border-hover):hover'
		);
		
		return $return_array;
		
	}
	
}

if ( !function_exists('aoki_qodef_max_image_width_srcset') ) {
	/**
	 * Set max width for srcset to 1920
	 *
	 * @return int
	 */
	function aoki_qodef_max_image_width_srcset() {
		return 1920;
	}
	
	add_filter('max_srcset_image_width', 'aoki_qodef_max_image_width_srcset');
}

if ( !function_exists('aoki_qodef_is_gutenberg_installed') ) {
	/**
	 * Function that checks if Gutenberg plugin installed
	 * @return bool
	 */
	function aoki_qodef_is_gutenberg_installed() {
		return function_exists('is_gutenberg_page') && is_gutenberg_page();
	}
}

if ( ! function_exists( 'aoki_qodef_is_wp_gutenberg_installed' ) ) {
	/**
	 * Function that checks if WordPress 5.x with Gutenberg editor installed
	 * @return bool
	 */
	function aoki_qodef_is_wp_gutenberg_installed() {
		return class_exists( 'WP_Block_Type' );
	}
}


if ( !function_exists('aoki_qodef_get_module_part') ) {
	function aoki_qodef_get_module_part($module) {
		return $module;
	}
}