(function($) {
    'use strict';

    var portfolio = {};
    qodef.modules.portfolio = portfolio;

    portfolio.qodefOnDocumentReady = qodefOnDocumentReady;
    portfolio.qodefOnWindowLoad = qodefOnWindowLoad;
    portfolio.qodefOnWindowResize = qodefOnWindowResize;
    portfolio.qodefOnWindowScroll = qodefOnWindowScroll;

    $(document).ready(qodefOnDocumentReady);
    $(window).load(qodefOnWindowLoad);
    $(window).resize(qodefOnWindowResize);
    $(window).scroll(qodefOnWindowScroll);

    
    /* 
     All functions to be called on $(document).ready() should be in this function
     */
    function qodefOnDocumentReady() {
        qodefPtfUncoverHover();
        qodefInitInteractiveLinkShowcase();
        qodefInitInteractiveLinkResizing();
        qodefILSIntroSizing();
        qodefILSIntroChars();
        qodefILSIntroScroll();
    }

    /*
     All functions to be called on $(window).load() should be in this function
     */
    function qodefOnWindowLoad() {
        qodefInitPortfolioMasonry();
        qodefInitPortfolioFilter();
        initPortfolioSingleMasonry();
        qodefInitPortfolioListAnimation();
	    qodefInitPortfolioPagination().init();
        qodefPortfolioSingleFollow().init();
        qodefPortfolioFullScreenSlider();
        qodefPFSSAnimation();
        qodefPortfolioSingleFullWidthSlider();
        qodefPortfolioHorizontalScroll();
        qodefInitPortfolioHorizontallyScrollingWidth();
    }


    /*
     All functions to be called on $(window).resize() should be in this function
     */
    function qodefOnWindowResize() {
        qodefInitPortfolioMasonry();
        qodefInitInteractiveLinkResizing();
        qodefILSIntroSizing();
        qodefPortfolioHorizontalScroll();
        qodefInitPortfolioHorizontallyScrollingWidth();
    }

    /*
     All functions to be called on $(window).scroll() should be in this function
     */
    function qodefOnWindowScroll() {
	    qodefInitPortfolioPagination().scroll();
    }

    /**
     * Initializes portfolio list article animation
     */
    function qodefInitPortfolioListAnimation(){
        var portList = $('.qodef-portfolio-list-holder.qodef-pl-has-animation');

        if(portList.length){
            portList.each(function(){
                var thisPortList = $(this).children('.qodef-pl-inner');

                thisPortList.children('article').each(function(l) {
                    var thisArticle = $(this);

                    thisArticle.appear(function() {
                        thisArticle.addClass('qodef-item-show');

                        setTimeout(function(){
                            thisArticle.addClass('qodef-item-shown');
                        }, 1000);
                    },{accX: 0, accY: 0});
                });
            });
        }
    }

    /**
     * Initializes portfolio list
     */
    function qodefInitPortfolioMasonry(){
        var portList = $('.qodef-portfolio-list-holder.qodef-pl-masonry');

        if(portList.length){
            portList.each(function(){
                var thisPortList = $(this),
                    masonry = thisPortList.children('.qodef-pl-inner'),
                    size = thisPortList.find('.qodef-pl-grid-sizer').width();
                
                qodefResizePortfolioItems(size, thisPortList);

                masonry.isotope({
                    layoutMode: 'packery',
                    itemSelector: 'article',
                    percentPosition: true,
                    packery: {
                        gutter: '.qodef-pl-grid-gutter',
                        columnWidth: '.qodef-pl-grid-sizer'
                    }
                });
                
                setTimeout(function () {
	                qodef.modules.common.qodefInitParallax();
                    qodefPtfUncoverHover();
                }, 600);

                masonry.css('opacity', '1');
            });
        }
    }

    /**
     * Init Resize Portfolio Items
     */
    function qodefResizePortfolioItems(size,container){
        if(container.hasClass('qodef-pl-images-fixed')) {
            var padding = parseInt(container.find('article').css('padding-left')),
                defaultMasonryItem = container.find('.qodef-pl-masonry-default'),
                largeWidthMasonryItem = container.find('.qodef-pl-masonry-large-width'),
                largeHeightMasonryItem = container.find('.qodef-pl-masonry-large-height'),
                largeWidthHeightMasonryItem = container.find('.qodef-pl-masonry-large-width-height');

            if (qodef.windowWidth > 680) {
                defaultMasonryItem.css('height', size - 2 * padding);
                largeHeightMasonryItem.css('height', Math.round(2 * size) - 2 * padding);
                largeWidthHeightMasonryItem.css('height', Math.round(2 * size) - 2 * padding);
                largeWidthMasonryItem.css('height', size - 2 * padding);
            } else {
                defaultMasonryItem.css('height', size);
                largeHeightMasonryItem.css('height', size);
                largeWidthHeightMasonryItem.css('height', size);
                largeWidthMasonryItem.css('height', Math.round(size / 2));
            }
        }
    }

    /**
     * Initializes portfolio masonry filter
     */
    function qodefInitPortfolioFilter(){
        var filterHolder = $('.qodef-portfolio-list-holder .qodef-pl-filter-holder');

        if(filterHolder.length){
            filterHolder.each(function(){
                var thisFilterHolder = $(this),
                    thisPortListHolder = thisFilterHolder.closest('.qodef-portfolio-list-holder'),
                    thisPortListInner = thisPortListHolder.find('.qodef-pl-inner'),
                    portListHasLoadMore = thisPortListHolder.hasClass('qodef-pl-pag-load-more') ? true : false;

                thisFilterHolder.find('.qodef-pl-filter:first').addClass('qodef-pl-current');
	            
	            if(thisPortListHolder.hasClass('qodef-pl-gallery')) {
		            thisPortListInner.isotope();
	            }

                thisFilterHolder.find('.qodef-pl-filter').on('click',function(){
                    var thisFilter = $(this),
                        filterValue = thisFilter.attr('data-filter'),
                        filterClassName = filterValue.length ? filterValue.substring(1) : '',
	                    portListHasArticles = thisPortListInner.children().hasClass(filterClassName) ? true : false;

                    thisFilter.parent().children('.qodef-pl-filter').removeClass('qodef-pl-current');
                    thisFilter.addClass('qodef-pl-current');
	
	                if(portListHasLoadMore && !portListHasArticles && filterValue.length) {
		                qodefInitLoadMoreItemsPortfolioFilter(thisPortListHolder, filterValue, filterClassName);
	                } else {
		                filterValue = filterValue.length === 0 ? '*' : filterValue;
                   
                        thisFilterHolder.parent().children('.qodef-pl-inner').isotope({ filter: filterValue });
	                    qodef.modules.common.qodefInitParallax();
                    }
                });
            });
        }
    }

    /**
     * Initializes load more items if portfolio masonry filter item is empty
     */
    function qodefInitLoadMoreItemsPortfolioFilter($portfolioList, $filterValue, $filterClassName) {
        var thisPortList = $portfolioList,
            thisPortListInner = thisPortList.find('.qodef-pl-inner'),
            filterValue = $filterValue,
            filterClassName = $filterClassName,
            maxNumPages = 0;

        if (typeof thisPortList.data('max-num-pages') !== 'undefined' && thisPortList.data('max-num-pages') !== false) {
            maxNumPages = thisPortList.data('max-num-pages');
        }

        var	loadMoreDatta = qodef.modules.common.getLoadMoreData(thisPortList),
            nextPage = loadMoreDatta.nextPage,
	        ajaxData = qodef.modules.common.setLoadMoreAjaxData(loadMoreDatta, 'qodef_core_portfolio_ajax_load_more'),
            loadingItem = thisPortList.find('.qodef-pl-loading');

        if(nextPage <= maxNumPages) {
            loadingItem.addClass('qodef-showing qodef-filter-trigger');
            thisPortListInner.css('opacity', '0');

            $.ajax({
                type: 'POST',
                data: ajaxData,
                url: qodefGlobalVars.vars.qodefAjaxUrl,
                success: function (data) {
                    nextPage++;
                    thisPortList.data('next-page', nextPage);
                    var response = $.parseJSON(data),
                        responseHtml = response.html;

                    thisPortList.waitForImages(function () {
                        thisPortListInner.append(responseHtml).isotope('reloadItems').isotope({sortBy: 'original-order'});
                        var portListHasArticles = !!thisPortListInner.children().hasClass(filterClassName);

                        if(portListHasArticles) {
                            setTimeout(function() {
                                qodefResizePortfolioItems(thisPortListInner.find('.qodef-pl-grid-sizer').width(), thisPortList);
                                thisPortListInner.isotope('layout').isotope({filter: filterValue});
                                loadingItem.removeClass('qodef-showing qodef-filter-trigger');

                                setTimeout(function() {
                                    thisPortListInner.css('opacity', '1');
                                    qodefInitPortfolioListAnimation();
	                                qodef.modules.common.qodefInitParallax();
                                }, 150);
                            }, 400);
                        } else {
                            loadingItem.removeClass('qodef-showing qodef-filter-trigger');
                            qodefInitLoadMoreItemsPortfolioFilter(thisPortList, filterValue, filterClassName);
                        }
                    });
                }
            });
        }
    }
	
	/**
	 * Initializes portfolio pagination functions
	 */
	function qodefInitPortfolioPagination(){
		var portList = $('.qodef-portfolio-list-holder');
		
		var initStandardPagination = function(thisPortList) {
			var standardLink = thisPortList.find('.qodef-pl-standard-pagination li');
			
			if(standardLink.length) {
				standardLink.each(function(){
					var thisLink = $(this).children('a'),
						pagedLink = 1;
					
					thisLink.on('click', function(e) {
						e.preventDefault();
						e.stopPropagation();
						
						if (typeof thisLink.data('paged') !== 'undefined' && thisLink.data('paged') !== false) {
							pagedLink = thisLink.data('paged');
						}

						initMainPagFunctionality(thisPortList, pagedLink);
					});
				});
			}
		};
		
		var initLoadMorePagination = function(thisPortList) {
			var loadMoreButton = thisPortList.find('.qodef-pl-load-more a');
			
			loadMoreButton.on('click', function(e) {
				e.preventDefault();
				e.stopPropagation();
				
				initMainPagFunctionality(thisPortList);
			});
		};
		
		var initInifiteScrollPagination = function(thisPortList) {
			var portListHeight = thisPortList.outerHeight(),
				portListTopOffest = thisPortList.offset().top,
				portListPosition = portListHeight + portListTopOffest - qodefGlobalVars.vars.qodefAddForAdminBar;
			
			if(!thisPortList.hasClass('qodef-pl-infinite-scroll-started') && qodef.scroll + qodef.windowHeight > portListPosition) {
				initMainPagFunctionality(thisPortList);
			}
		};
		
		var initMainPagFunctionality = function(thisPortList, pagedLink) {
			var thisPortListInner = thisPortList.find('.qodef-pl-inner'),
				nextPage,
				maxNumPages;
			
			if (typeof thisPortList.data('max-num-pages') !== 'undefined' && thisPortList.data('max-num-pages') !== false) {
				maxNumPages = thisPortList.data('max-num-pages');
			}
			
			if(thisPortList.hasClass('qodef-pl-pag-standard')) {
				thisPortList.data('next-page', pagedLink);
			}
			
			if(thisPortList.hasClass('qodef-pl-pag-infinite-scroll')) {
				thisPortList.addClass('qodef-pl-infinite-scroll-started');
			}
			
			var loadMoreDatta = qodef.modules.common.getLoadMoreData(thisPortList),
				loadingItem = thisPortList.find('.qodef-pl-loading');
			
			nextPage = loadMoreDatta.nextPage;
			if(nextPage <= maxNumPages || maxNumPages === 0){
				if(thisPortList.hasClass('qodef-pl-pag-standard')) {
					loadingItem.addClass('qodef-showing qodef-standard-pag-trigger');
					thisPortList.addClass('qodef-pl-pag-standard-animate');
				} else {
					loadingItem.addClass('qodef-showing');
				}
				
				var ajaxData = qodef.modules.common.setLoadMoreAjaxData(loadMoreDatta, 'qodef_core_portfolio_ajax_load_more');
				
				$.ajax({
					type: 'POST',
					data: ajaxData,
					url: qodefGlobalVars.vars.qodefAjaxUrl,
					success: function (data) {
						if(!thisPortList.hasClass('qodef-pl-pag-standard')) {
							nextPage++;
						}
						
						thisPortList.data('next-page', nextPage);
						
						var response = $.parseJSON(data),
							responseHtml =  response.html;
						
						if(thisPortList.hasClass('qodef-pl-pag-standard')) {
							qodefInitStandardPaginationLinkChanges(thisPortList, maxNumPages, nextPage);
							
							thisPortList.waitForImages(function(){
								if(thisPortList.hasClass('qodef-pl-masonry')){
									qodefInitHtmlIsotopeNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
								} else if (thisPortList.hasClass('qodef-pl-gallery') && thisPortList.hasClass('qodef-pl-has-filter')) {
									qodefInitHtmlIsotopeNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
								} else {
									qodefInitHtmlGalleryNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
								}
							});
						} else {
							thisPortList.waitForImages(function(){
								if(thisPortList.hasClass('qodef-pl-masonry')){
								    if(pagedLink === 1) {
                                        qodefInitHtmlIsotopeNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
                                    } else {
                                        qodefInitAppendIsotopeNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
                                    }
								} else if (thisPortList.hasClass('qodef-pl-gallery') && thisPortList.hasClass('qodef-pl-has-filter') && pagedLink != 1) {
									qodefInitAppendIsotopeNewContent(thisPortList, thisPortListInner, loadingItem, responseHtml);
								} else {
									qodefInitAppendGalleryNewContent(thisPortListInner, loadingItem, responseHtml);
								}
							});
						}
						
						if(thisPortList.hasClass('qodef-pl-infinite-scroll-started')) {
							thisPortList.removeClass('qodef-pl-infinite-scroll-started');
						}
					}
				});
			}
			
			if(nextPage >= maxNumPages){
				thisPortList.find('.qodef-pl-load-more-holder').hide();
			}
		};
		
		var qodefInitStandardPaginationLinkChanges = function(thisPortList, maxNumPages, nextPage) {
			var standardPagHolder = thisPortList.find('.qodef-pl-standard-pagination'),
				standardPagNumericItem = standardPagHolder.find('li.qodef-pl-pag-number'),
				standardPagPrevItem = standardPagHolder.find('li.qodef-pl-pag-prev a'),
				standardPagNextItem = standardPagHolder.find('li.qodef-pl-pag-next a');
			
			standardPagNumericItem.removeClass('qodef-pl-pag-active');
			standardPagNumericItem.eq(nextPage-1).addClass('qodef-pl-pag-active');
			
			standardPagPrevItem.data('paged', nextPage-1);
			standardPagNextItem.data('paged', nextPage+1);
			
			if(nextPage > 1) {
				standardPagPrevItem.css({'opacity': '1'});
			} else {
				standardPagPrevItem.css({'opacity': '0'});
			}
			
			if(nextPage === maxNumPages) {
				standardPagNextItem.css({'opacity': '0'});
			} else {
				standardPagNextItem.css({'opacity': '1'});
			}
		};
		
		var qodefInitHtmlIsotopeNewContent = function(thisPortList, thisPortListInner, loadingItem, responseHtml) {
            thisPortListInner.find('article').remove();
            thisPortListInner.append(responseHtml);
            qodefResizePortfolioItems(thisPortListInner.find('.qodef-pl-grid-sizer').width(), thisPortList);
            thisPortListInner.isotope('reloadItems').isotope({sortBy: 'original-order'});
			loadingItem.removeClass('qodef-showing qodef-standard-pag-trigger');
			thisPortList.removeClass('qodef-pl-pag-standard-animate');
			
			setTimeout(function() {
				thisPortListInner.isotope('layout');
				qodefInitPortfolioListAnimation();
				qodef.modules.common.qodefInitParallax();
                qodefPtfUncoverHover();
			}, 600);
		};
		
		var qodefInitHtmlGalleryNewContent = function(thisPortList, thisPortListInner, loadingItem, responseHtml) {
			loadingItem.removeClass('qodef-showing qodef-standard-pag-trigger');
			thisPortList.removeClass('qodef-pl-pag-standard-animate');
			thisPortListInner.html(responseHtml);
			qodefInitPortfolioListAnimation();
			qodef.modules.common.qodefInitParallax();
            qodefPtfUncoverHover();
		};
		
		var qodefInitAppendIsotopeNewContent = function(thisPortList, thisPortListInner, loadingItem, responseHtml) {
            thisPortListInner.append(responseHtml);
            qodefResizePortfolioItems(thisPortListInner.find('.qodef-pl-grid-sizer').width(), thisPortList);
            thisPortListInner.isotope('reloadItems').isotope({sortBy: 'original-order'});
			loadingItem.removeClass('qodef-showing');
			
			setTimeout(function() {
				thisPortListInner.isotope('layout');
				qodefInitPortfolioListAnimation();
				qodef.modules.common.qodefInitParallax();
                qodefPtfUncoverHover();
			}, 600);
		};
		
		var qodefInitAppendGalleryNewContent = function(thisPortListInner, loadingItem, responseHtml) {
			loadingItem.removeClass('qodef-showing');
			thisPortListInner.append(responseHtml);
			qodefInitPortfolioListAnimation();
			qodef.modules.common.qodefInitParallax();
            qodefPtfUncoverHover();
		};
		
		return {
			init: function() {
				if(portList.length) {
					portList.each(function() {
						var thisPortList = $(this);
						
						if(thisPortList.hasClass('qodef-pl-pag-standard')) {
							initStandardPagination(thisPortList);
						}
						
						if(thisPortList.hasClass('qodef-pl-pag-load-more')) {
							initLoadMorePagination(thisPortList);
						}
						
						if(thisPortList.hasClass('qodef-pl-pag-infinite-scroll')) {
							initInifiteScrollPagination(thisPortList);
						}
					});
				}
			},
			scroll: function() {
				if(portList.length) {
					portList.each(function() {
						var thisPortList = $(this);
						
						if(thisPortList.hasClass('qodef-pl-pag-infinite-scroll')) {
							initInifiteScrollPagination(thisPortList);
						}
					});
				}
			},
            getMainPagFunction: function(thisPortList, paged) {
                initMainPagFunctionality(thisPortList, paged);
            }
		};
	}
	
	var qodefPortfolioSingleFollow = function() {
		var info = $('.qodef-follow-portfolio-info .qodef-portfolio-single-holder .qodef-ps-info-sticky-holder');
		
		if (info.length) {
			var infoHolder = info.parent(),
				infoHolderOffset = infoHolder.offset().top,
				infoHolderHeight = infoHolder.height(),
				mediaHolder = $('.qodef-ps-image-holder'),
				mediaHolderHeight = mediaHolder.height(),
				header = $('.header-appear, .qodef-fixed-wrapper'),
				headerHeight = (header.length) ? header.height() : 0;
		}
		
		var infoHolderPosition = function() {
			if(info.length) {
				if (mediaHolderHeight > infoHolderHeight) {
					if(qodef.scroll > infoHolderOffset) {
						var marginTop = qodef.scroll - infoHolderOffset + qodefGlobalVars.vars.qodefAddForAdminBar + headerHeight;
						// if scroll is initially positioned below mediaHolderHeight
						if(marginTop + infoHolderHeight > mediaHolderHeight){
							marginTop = mediaHolderHeight - infoHolderHeight;
						}
						info.stop().animate({
							marginTop: marginTop
						});
					}
				}
			}
		};
		
		var recalculateInfoHolderPosition = function() {
			if (info.length) {
				if(mediaHolderHeight > infoHolderHeight) {
					if(qodef.scroll > infoHolderOffset) {
						
						if(qodef.scroll + headerHeight + qodefGlobalVars.vars.qodefAddForAdminBar + infoHolderHeight + 50 < infoHolderOffset + mediaHolderHeight) { //50 to prevent mispositioning
							
							//Calculate header height if header appears
							if ($('.header-appear, .qodef-fixed-wrapper').length) {
								headerHeight = $('.header-appear, .qodef-fixed-wrapper').height();
							}
							info.stop().animate({
								marginTop: (qodef.scroll - infoHolderOffset + qodefGlobalVars.vars.qodefAddForAdminBar + headerHeight)
							});
							//Reset header height
							headerHeight = 0;
						}
						else{
							info.stop().animate({
								marginTop: mediaHolderHeight - infoHolderHeight
							});
						}
					} else {
						info.stop().animate({
							marginTop: 0
						});
					}
				}
			}
		};
		
		return {
			init : function() {
				infoHolderPosition();
				$(window).scroll(function(){
					recalculateInfoHolderPosition();
				});
			}
		};
	};
	
	function initPortfolioSingleMasonry(){
		var masonryHolder = $('.qodef-portfolio-single-holder .qodef-ps-masonry-images'),
			masonry = masonryHolder.children();
		
		if(masonry.length){
            masonry.isotope({
                layoutMode: 'packery',
                itemSelector: '.qodef-ps-image',
                percentPosition: true,
                packery: {
                    gutter: '.qodef-ps-grid-gutter',
                    columnWidth: '.qodef-ps-grid-sizer'
                }
            });

            masonry.css('opacity', '1');
		}
	};

    var qodefPortfolioFullScreenSlider = function() {
        var FullScreenSliders = $('.qodef-portfolio-fs-slider');
        FullScreenSliders.each(function () {

            var slider = $(this);
            var dataHolder = $(this).parent();
            var mobileHeaderHeight = $('.qodef-mobile-header').height();

            var loop = true,
                autoplay = false,
                sliderSpeed = 5000,
                numberOfItems = 3,
                navigation = false;

            if( dataHolder.data('enable-autoplay') === 'yes' ){
                autoplay = true;
            }

            if( dataHolder.data('enable-navigation') === 'yes' ){
                navigation = true;
            }

            if (typeof dataHolder.data('number-of-columns') !== 'undefined' && dataHolder.data('number-of-columns') !== false) {
                numberOfItems = dataHolder.data('number-of-columns');
            }

            if (dataHolder.data('enable-loop') === 'no') {
                loop = false;
            }

            if (typeof dataHolder.data('slider-speed') !== 'undefined' && dataHolder.data('slider-speed') !== false) {
                sliderSpeed = dataHolder.data('slider-speed');
            }


            slider.on('init', function(slick){
                changeOnScroll();
            });

            var changeOnScroll = function () {
                slider.mousewheel(function (e) {
                    e.preventDefault();

                    if (e.deltaY < 0) {
                        slider.slick("slickNext");
                    }
                    else {
                        slider.slick("slickPrev");
                    }
                });
            };

            slider.slick({
                autoplay: autoplay,
                infinite: loop,
                slidesToShow: numberOfItems,
                autoplaySpeed: sliderSpeed,
                slidesToScroll: 1,
                arrows: false,
                dots: false,
                responsive: [
                    {
                        breakpoint: 600,
                        settings: "unslick"
                    }
                ]
            });

            if(qodef.windowWidth < 600){
                var article = slider.find('.portfolio-item');
                article.each(function () {
                    $(this).height((qodef.windowHeight-mobileHeaderHeight)/3);
                });
            }

        })
    };

    function qodefPFSSAnimation() {
        var FullScreenSliders = $('.qodef-portfolio-fs-slider');
        FullScreenSliders.each(function () {

            var slides = $(this).find('article');
            slides.each(function () {
                var excerpt = $(this).find('.qodef-pli-excerpt'),
                    height = 0;

                if(excerpt.length > 0 ){
                    console.log('test');

                    height = excerpt.outerHeight();
                    excerpt.css('margin-bottom', height * (-1));
                };

                $(this).mouseenter(function () {
                    excerpt.css('margin-bottom', 0);
                });

                $(this).mouseleave(function () {
                    excerpt.css('margin-bottom', height * (-1));
                });
            })
        });
    };

    /**
     * Init item showcase shortcode
     */
    function qodefInitInteractiveLinkShowcase() {
        var interactiveLinkShowcase = $('.qodef-ips');

        if (interactiveLinkShowcase.length && !qodef.htmlEl.hasClass('touch')) {
            interactiveLinkShowcase.each(function(){
                var thisInteractiveLinkShowcase = $(this),
                    items = thisInteractiveLinkShowcase.find('.qodef-ips-item-content');

                // var windowHeight = qodef.windowWidth > 1024 ? qodef.windowHeight : qodef.windowHeight - qodefGlobalVars.vars.qodefMobileHeaderHeight;

                if (qodef.windowWidth > 1024) {
                    // thisInteractiveLinkShowcase.css('height', windowHeight);
                    thisInteractiveLinkShowcase.css('width', qodef.windowWidth);
                }
                var singleImage = thisInteractiveLinkShowcase.find('.qodef-ips-item-image'),
                    singleLink  = thisInteractiveLinkShowcase.find('.qodef-ips-item-link');

                singleLink.parent().addClass('loaded');

                singleLink.on('mouseenter', function() {
                    singleImage.removeClass('active');
                    singleLink.parent().removeClass('active');
                    var thisLink = $(this),
                        index = thisLink.parent().index();
                    thisLink.parent().addClass('active');
                    thisLink.parent().siblings().addClass('idle');
                    singleImage.eq(index).addClass('active');
                });

                singleLink.on('mouseleave', function() {
                    singleImage.removeClass('active');
                    singleLink.parent().removeClass('active idle');
                });

                if (thisInteractiveLinkShowcase.hasClass('qodef-ips-with-scroll')) {
                    var contentHolder = thisInteractiveLinkShowcase.find('.qodef-ips-content-table-cell'),
                        height = 0,
                        cycle = 0;

                    var paddingAdj = items.first().height();
                    if(qodef.windowWidth >= 1024 && qodef.windowWidth < 1440){
                        paddingAdj -= 25;
                    }
                    console.log(paddingAdj);
                    contentHolder.css('padding-top', paddingAdj);

                    items.each(function(){
                        var item = $(this),
                            visible = false;

                        var showItem = function() {
                            item.removeClass('qodef-up qodef-down');
                            item.addClass('qodef-appeared');
                            visible = true;
                        };

                        var hideItem = function() {
                            item.removeClass('qodef-appeared');
                            if ((item.offset().top < $(window).scrollTop() + paddingAdj)) {
                                item.removeClass('qodef-down');
                                item.addClass('qodef-up');
                            } else {
                                item.removeClass('qodef-up');
                                item.addClass('qodef-down');
                            }
                            visible = false;
                        };

                        //init logic
                        if ((item.offset().top >= $(window).scrollTop() + paddingAdj/2) && (item.offset().top + item.height() < $(window).scrollTop() + $(window).height() - paddingAdj/2)) {
                            showItem();
                        } else {
                            hideItem();
                        }

                        //scroll logic
                        $(window).scroll(function(){
                            if ((item.offset().top >= $(window).scrollTop() + paddingAdj/2) && (item.offset().top + item.height() < $(window).scrollTop() + $(window).height() - paddingAdj/2)) {
                                if (!visible) {
                                    showItem();
                                }
                            } else {
                                if (visible) {
                                    hideItem();
                                }
                            }
                        });
                    });
                }
            });
        }
    }

    function qodefInitInteractiveLinkResizing(){
        var interactiveLinkShowcase = $('.qodef-ips');

        if (interactiveLinkShowcase.length) {
            interactiveLinkShowcase.each(function(){
                var thisInteractiveLinkShowcase = $(this),
                    items = thisInteractiveLinkShowcase.find('.qodef-ips-item-content .qodef-ips-item-link'),
                    itemsCopy = thisInteractiveLinkShowcase.find('.qodef-ips-item-content-copy .qodef-ips-item-link');

                items.each(function (e) {
                    var thisItem = $(this),
                        thisItemCopy = itemsCopy.eq(e),
                        itemFontSize = parseInt(thisItem.css('font-size')),
                        coef1 = 1,
                        coef2 = 1;

                    if (typeof(thisItem.data('font-size')) === 'undefined'){
                        thisItem.data('font-size',itemFontSize);
                    } else {
                        itemFontSize = thisItem.data('font-size');
                    }

                    if (qodef.windowWidth < 1400){
                        coef2 = 0.85;
                    }

                    if (qodef.windowWidth < 1300){
                        coef1 = 0.8;
                        coef2 = 0.7;
                    }

                    if (qodef.windowWidth < 1024){
                        coef1 = 0.7;
                        coef2 = 0.6;
                    }

                    if (qodef.windowWidth < 769){
                        coef1 = 0.6;
                        coef2 = 0.5;
                    }

                    if (qodef.windowWidth < 600){
                        coef1 = 0.5;
                        coef2 = 0.4;
                    }

                    if (qodef.windowWidth < 480){
                        coef1 = 0.4;
                        coef2 = 0.27;
                    }


                    if  (itemFontSize > 100){
                        itemFontSize = Math.round(itemFontSize*coef2);
                    }
                    else if (itemFontSize > 50) {
                        itemFontSize = Math.round(itemFontSize*coef1);
                    }

                    thisItem.css('font-size',itemFontSize + 'px');
                    thisItemCopy.css('font-size',itemFontSize + 'px');
                });
            });
        }

    }

    function qodefILSIntroSizing() {
        var introSection = $('#qodef-ips-intro');

        if (introSection.length) {
            var contWidth = introSection.width(),
                txtEl = introSection.find('.qodef-ips-intro-text'),
                nbChars = txtEl.find('> span').text().length,
                relSize = contWidth/nbChars,
                coeff = 1.6;
               
            introSection.css('height', qodef.windowHeight - introSection.offset().top);

            txtEl.css({
                'font-size': relSize*coeff,
                'visibility': 'visible'
            });
        }
    }

    function qodefILSIntroChars() {
        var intro = $('#qodef-ips-intro');

        if (intro.length) {
            var txtHolder = intro.find('.qodef-ips-intro-text span'),
                txt = txtHolder.text(),
                newTxt = txt.replace(/\w|\./g, function(c){
                    return '<span class="qodef-char-mask"><span>'+c+'</span></span>';
                });

            txtHolder.html(newTxt);

            var charMasks = intro.find('.qodef-char-mask'),
                charEls = charMasks.find('span');

            charMasks.each(function(i){
                var mask = $(this),
                    charEl = mask.find('span');

                if (mask.text() === '.') {
                    mask.addClass('qodef-dot');
                }

                setTimeout(function(){
                    charEl.addClass('qodef-appeared');
                }, (i*150 - 20));
            });

            charMasks.last().find('span').one(qodef.transitionEnd, function(){
                $(document).trigger('qodefIntroCharsVisible');
            });
        }
    }

    function qodefILSIntroScroll() {
        var introSection = $('#qodef-ips-intro');

        if (introSection.length && !qodef.htmlEl.hasClass('touch')) {
            var introHolder = introSection,
                introHolderHeight = introHolder.height(),
                introHolderOffset = introHolder.offset().top,
                introArea = introHolderHeight - introHolderOffset,
                pageJumped = false,
                normalScroll = true,
                set = false;

            var qodefScrollHandler = function() {
                if  ($(window).scrollTop() < introArea) {
                    normalScroll = false;
                } 

                function qodefScrollTo() {
                    pageJumped = true;
                    $('header').animate({opacity:0}, 300,'easeInOutQuint'); //custom header fade out
                    introSection.parent().addClass('qodef-remove-intro'); //remove section, no back scroll
                    $('html, body').animate({
                        scrollTop: introArea
                    }, 1000, 'easeInOutQuint', function() {
                        introSection.remove(); //remove section, no back scroll
                        $('html, body').animate({
                            scrollTop: 0
                        }, 0, function(){
                            $('header').animate({opacity:1},'easeInOutQuint', function(){
                                normalScroll = true;
                            }); //custom header fade in
                        });
                    });
                }

                window.addEventListener('wheel', function(event) {
                    var scroll = event.deltaY,
                        scrollingForward = false;

                    if (scroll > 0) {
                        scrollingForward = true;
                    } else {
                        scrollingForward = false;
                    }

                    if (!pageJumped && !normalScroll) {
                        if (scrollingForward && ($(window).scrollTop() < introArea)) {
                            event.preventDefault();
                            qodefScrollTo();
                        }
                    } else {
                        if (!normalScroll) {
                            event.preventDefault();
                        }
                    }
                }, {passive: false});

                //scrollbar click
                $(document).on('mousedown', function(event){
                    if( $(window).outerWidth() <= event.pageX ){
                        if ($(window).scrollTop() === introHolderOffset) {
                            event.preventDefault();
                            qodefScrollTo();
                        }
                    }
                });
            }

            //prevent mousewheel scroll
            window.addEventListener('wheel', function (event) {
                if (!set || !pageJumped) {
                    event.preventDefault();
                }
            }, {passive: false});

            //prevent scrollbar scroll
            window.addEventListener('scroll', function () {
                if (!set || !pageJumped) {
                    $(window).scrollTop(introHolderOffset);
                }
            });  

            //init
            $(document).one('qodefIntroCharsVisible', function(){
                set = true;
                qodefScrollHandler();
            });  
        }
    }

    function qodefPortfolioSingleFullWidthSlider(){
        var sliders = $('.qodef-ps-full-width-slider');
        sliders.each(function () {
            var slider = $(this);

            slider.slick({
                autoplay: true,
                infinite: true,
                centerMode: true,
                slidesToShow: 1,
                arrows: false,
                dots: true,
                variableWidth: true
            });

            var flag, mousedownFlag, moved;

            slider.on("mousedown", function(){
                flag = 0;
                mousedownFlag = 1;
                moved = false;
            });

            slider.on("mousemove", function(){
                if (mousedownFlag === 1){
                    if (moved){
                        flag = 1;
                    }
                    moved = true;
                }
            });

            slider.on("mouseleave", function(){
                flag = 0;
            });

            slider.on("mouseup", function(e){
                if(flag === 1){
                    slider.find('a[data-rel^="prettyPhoto"]').off('click');
                }
                else{
                    qodef.modules.common.qodefPrettyPhoto();
                }
                flag = 0;
                mousedownFlag = 0;
            });
        });
    }

    function qodefPortfolioHorizontalScroll() {

        if (qodef.windowWidth >= 1024) {

            if($('.qodef-horizontally-scrolling-portfolio-list-page').length){

                $('html').addClass('qodef-horizontally-scrolling-html');
                $('body').addClass('qodef-horizontally-scrolling-portfolio');

                var contentWrapper = $('body').find('.qodef-wrapper');
                contentWrapper.prepend('<div class="qodef-hsf-frame-left"></div>');
                contentWrapper.prepend('<div class="qodef-hsf-frame-right"></div>');

                $(window).mousewheel(function (event, delta) {
                    if (Math.abs(delta) >= 20)
                        delta /= 20;


                    event.preventDefault();
                    var curScroll = {
                        x: qodef.modules.common.qodefgetScrollX(),
                        y: qodef.modules.common.qodefgetScrollY()
                    };

                    TweenMax.to(curScroll, 0.5, {
                        x: curScroll.x - (delta * 500),
                        onUpdate: function () {
                            window.scrollTo(curScroll.x, curScroll.y);
                        }
                    });
                });

            }
        }

    }

    function qodefInitPortfolioHorizontallyScrollingWidth(){
        var hsp = $('.qodef-horizontally-scrolling-portfolio-list-holder');
        if(hsp.length){

            var fullHeaderHeight = qodefGlobalVars.vars.qodefMenuAreaHeight + qodefGlobalVars.vars.qodefLogoAreaHeight;

            if (qodef.windowWidth  >= 1024) {
                 var frameLeft = $('.qodef-hsf-frame-left'),
                    frameRight = $('.qodef-hsf-frame-right'),
                    qodefWrapper = $('.qodef-wrapper'),
                    headerInner = $('.qodef-page-header .qodef-vertical-align-containers');

                frameLeft.css('padding-left', fullHeaderHeight);
                frameRight.css('padding-right', fullHeaderHeight);
                qodefWrapper.css('padding-left', fullHeaderHeight);
                qodefWrapper.css('padding-right', fullHeaderHeight);
                headerInner.css('padding-left', fullHeaderHeight);
                headerInner.css('padding-right', fullHeaderHeight);
            }

            if (qodef.windowWidth  > 680) {
                var header = $('.qodef-page-header'),
                    mobileHeader = $('.qodef-mobile-header');


                header.css('margin-top', fullHeaderHeight);
                mobileHeader.css('margin-top',qodefGlobalVars.vars.qodefMobileHeaderHeight);

                hsp.each(function(){
                    var holder = $(this),
                        rows = holder.find('.qodef-hspl-images-row'),
                        completeWidth = 0,
                        passepartout = $('.qodef-paspartu-enabled .qodef-wrapper'),
                        passepartoutWidth = 0,
                        holderHeight;

                    if (passepartout.length){
                        passepartoutWidth = parseInt(passepartout.css('paddingLeft'));

                        //if top not disabled
                        if (! $('.qodef-paspartu-enabled').hasClass('qodef-top-paspartu-disabled')){
                            passepartoutWidth += passepartoutWidth;
                        }
                    }

                    holder.waitForImages(function() {

                        //if main header visible
                        if (header.is(':visible')){
                            holderHeight = qodef.windowHeight - passepartoutWidth - ((qodefGlobalVars.vars.qodefMenuAreaHeight + qodefGlobalVars.vars.qodefLogoAreaHeight)*2);
                        } else {
                            holderHeight = qodef.windowHeight - passepartoutWidth - qodefGlobalVars.vars.qodefMobileHeaderHeight*2;

                        }
                        holder.height(holderHeight);

                        if(rows.length) {
                            rows.each(function() {
                                var row = $(this);
                                var rowArticles = row.find('article');

                                var allArticles = holder.find('.qodef-hspl-images-row').find('article');
                                allArticles.each(function(){
                                    var article = $(this),
                                        articleImage = article.find('img'),
                                        articleImageWidth = articleImage.attr('width'),
                                        articleImageHeight = articleImage.attr('height'),
                                        articleRatio = articleImageWidth/articleImageHeight,
                                        articleWidth = Math.ceil(row.height() * articleRatio);

                                    article.width(articleWidth);

                                });
                                var tempCompleteWidth = 0;
                                rowArticles.each(function(){
                                    var article = $(this);
                                    tempCompleteWidth = tempCompleteWidth + article.outerWidth();
                                });
                                completeWidth = tempCompleteWidth > completeWidth ? tempCompleteWidth : completeWidth;
                            });
                        }

                        holder.width(completeWidth + passepartoutWidth); // Bottom Passepartout is same like left and right and beacause of that we use it here instead of right
                        holder.css('opacity', 1);
                    });

                })
            }
            else {
                hsp.css('opacity', 1);
            }
        }
    }

    function qodefPtfUncoverHover() {
        var uncoverLists = $('.qodef-pl-gallery-overlay-shader');

        if (uncoverLists.length && !qodef.htmlEl.hasClass('touch')) {
            uncoverLists.each(function() {
                var list = $(this),
                    items = uncoverLists.find('article');

                //split words, add char masks
                items.not('.qodef-with-char-mask').each(function(){
                    var item = $(this).addClass('qodef-with-char-mask'),
                        uncoverTitle = item.find('.qodef-pli-title'),
                        text = uncoverTitle.html().split(' '),
                        len = text.length,
                        result = []; 

                    for( var i = 0; i < len; i++ ) {
                        result[i] = '<span class="qodef-word">' + text[i] + '</span>';
                    }
                    uncoverTitle.html(result.join(' '));  

                    var words = item.find('.qodef-word');

                    words.each(function(){
                        var word = $(this),
                            charEl = word.text(),
                            newTxt = charEl.replace(/\w|\W/g, function(c){
                                return '<span class="qodef-char-mask"><span>'+c+'</span></span>';
                            });

                        word.html(newTxt);
                    });
                });
            });
        }
    }

})(jQuery);