<?php
namespace QodeCore\CPT\Shortcodes\CallToAction;

use QodeCore\Lib;

class CallToAction implements Lib\ShortcodeInterface {
	private $base;
	
	public function __construct() {
		$this->base = 'qodef_call_to_action';
		
		add_action( 'vc_before_init', array( $this, 'vcMap' ) );
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		if ( function_exists( 'vc_map' ) ) {
			vc_map(
				array(
					'name'                      => esc_html__( 'Select Call To Action', 'select-core' ),
					'base'                      => $this->getBase(),
					'category'                  => esc_html__( 'by SELECT', 'select-core' ),
					'icon'                      => 'icon-wpb-call-to-action extended-custom-icon',
					'allowed_container_element' => 'vc_row',
					'params'                    => array_merge(
					    array(
					        array(
                            'type'        => 'textfield',
                            'param_name'  => 'custom_class',
                            'heading'     => esc_html__( 'Custom CSS Class', 'select-core' ),
                            'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS', 'select-core' )
                            ),
                            array(
                                'type'        => 'dropdown',
                                'param_name'  => 'type',
                                'heading'     => esc_html__( 'Type', 'select-core' ),
                                'value'       => array(
                                    esc_html__( 'Normal', 'select-core' ) => 'normal',
                                    esc_html__( 'Simple', 'select-core' ) => 'simple'
                                ),
                                'save_always' => true
                            ),
                        ),
                        aoki_qodef_icon_collections()->getVCParamsArray( array('element' => 'type', 'value' => 'simple') ),
                        array(
                            array(
                                'type'       => 'textfield',
                                'param_name' => 'custom_icon_size',
                                'heading'    => esc_html__( 'Set Icon Size', 'select-core' ),
                                'dependency' => array( 'element' => 'type', 'value' => array( 'simple' ) )
                            ),
                            array(
                                'type'       => 'textfield',
                                'param_name' => 'link',
                                'heading'    => esc_html__( 'Link', 'select-core' ),
                                'dependency' => array( 'element' => 'type', 'value' => array( 'simple' ) )
                            ),
                            array(
                                'type'       => 'dropdown',
                                'param_name' => 'link_skin',
                                'heading'    => esc_html__( 'Skin', 'select-core' ),
                                'value'      => array(
                                    esc_html__('Default', 'select-core') => '',
                                    esc_html__('Light', 'select-core')   => 'qodef-cta-light-skin',
                                ),
                                'dependency' => array( 'element' => 'type', 'value' => array( 'simple' ) )
                            ),
                            array(
                                'type'       => 'dropdown',
                                'param_name' => 'content_in_grid',
                                'heading'    => esc_html__( 'Set Content In Grid', 'select-core' ),
                                'value'      => array_flip( aoki_qodef_get_yes_no_select_array( false ) ),
                                'dependency' => array( 'element' => 'type', 'value' => array( 'normal' ) )
                            ),
                            array(
                                'type'       => 'dropdown',
                                'param_name' => 'content_elements_proportion',
                                'heading'    => esc_html__( 'Content Elements Proportion', 'select-core' ),
                                'value'      => array(
                                    esc_html__( '80/20', 'select-core' ) => '80',
                                    esc_html__( '75/25', 'select-core' ) => '75',
                                    esc_html__( '66/33', 'select-core' ) => '66',
                                    esc_html__( '50/50', 'select-core' ) => '50'
                                ),
                                'dependency' => array( 'element' => 'type', 'value' => array( 'normal' ) )
                            ),
                            array(
                                'type'        => 'textfield',
                                'param_name'  => 'button_text',
                                'heading'     => esc_html__( 'Button Text', 'select-core' ),
                                'value'       => esc_html__( 'Button Text', 'select-core' ),
                                'dependency' => array( 'element' => 'type', 'value' => array( 'normal' ) ),
                                'save_always' => true
                            ),
                            array(
                                'type'       => 'textfield',
                                'param_name' => 'button_top_margin',
                                'heading'    => esc_html__( 'Button Top Margin (px)', 'select-core' ),
                                'dependency' => array( 'element' => 'type', 'value' => array( 'normal' ) ),
                                'group'      => esc_html__( 'Button Style', 'select-core' )
                            ),
                            array(
                                'type'        => 'dropdown',
                                'param_name'  => 'button_type',
                                'heading'     => esc_html__( 'Button Type', 'select-core' ),
                                'value'       => array(
                                    esc_html__( 'Solid', 'select-core' )   => 'solid',
                                    esc_html__( 'Outline', 'select-core' ) => 'outline'
                                ),
                                'save_always' => true,
                                'dependency' => array( 'element' => 'type', 'value' => array( 'normal' ) ),
                                'group'       => esc_html__( 'Button Style', 'select-core' )
                            ),
                            array(
                                'type'        => 'dropdown',
                                'param_name'  => 'button_size',
                                'heading'     => esc_html__( 'Button Size', 'select-core' ),
                                'value'       => array(
                                    esc_html__( 'Default', 'select-core' ) => '',
                                    esc_html__( 'Small', 'select-core' )   => 'small',
                                    esc_html__( 'Medium', 'select-core' )  => 'medium',
                                    esc_html__( 'Large', 'select-core' )   => 'large'
                                ),
                                'save_always' => true,
                                'dependency'  => array(
                                    'element' => 'button_type',
                                    'value'   => array( 'solid', 'outline' )
                                ),
                                'group'       => esc_html__( 'Button Style', 'select-core' )
                            ),
                            array(
                                'type'       => 'textfield',
                                'param_name' => 'button_link',
                                'heading'    => esc_html__( 'Button Link', 'select-core' ),
                                'dependency' => array( 'element' => 'type', 'value' => array( 'normal' ) ),
                                'group'      => esc_html__( 'Button Style', 'select-core' )
                            ),
                            array(
                                'type'       => 'dropdown',
                                'param_name' => 'button_target',
                                'heading'    => esc_html__( 'Button Link Target', 'select-core' ),
                                'value'      => array_flip( aoki_qodef_get_link_target_array() ),
                                'dependency' => array( 'element' => 'type', 'value' => array( 'normal' ) ),
                                'group'      => esc_html__( 'Button Style', 'select-core' )
                            ),
                            array(
                                'type'       => 'colorpicker',
                                'param_name' => 'button_color',
                                'heading'    => esc_html__( 'Button Color', 'select-core' ),
                                'dependency' => array( 'element' => 'type', 'value' => array( 'normal' ) ),
                                'group'      => esc_html__( 'Button Style', 'select-core' )
                            ),
                            array(
                                'type'       => 'colorpicker',
                                'param_name' => 'button_hover_color',
                                'heading'    => esc_html__( 'Button Hover Color', 'select-core' ),
                                'dependency' => array( 'element' => 'type', 'value' => array( 'normal' ) ),
                                'group'      => esc_html__( 'Button Style', 'select-core' )
                            ),
                            array(
                                'type'       => 'colorpicker',
                                'param_name' => 'button_background_color',
                                'heading'    => esc_html__( 'Button Background Color', 'select-core' ),
                                'dependency' => array( 'element' => 'button_type', 'value' => array( 'solid' ) ),
                                'group'      => esc_html__( 'Button Style', 'select-core' )
                            ),
                            array(
                                'type'       => 'colorpicker',
                                'param_name' => 'button_hover_background_color',
                                'heading'    => esc_html__( 'Button Hover Background Color', 'select-core' ),
                                'dependency' => array( 'element' => 'type', 'value' => array( 'normal' ) ),
                                'group'      => esc_html__( 'Button Style', 'select-core' )
                            ),
                            array(
                                'type'       => 'colorpicker',
                                'param_name' => 'button_border_color',
                                'heading'    => esc_html__( 'Button Border Color', 'select-core' ),
                                'dependency' => array( 'element' => 'type', 'value' => array( 'normal' ) ),
                                'group'      => esc_html__( 'Button Style', 'select-core' )
                            ),
                            array(
                                'type'       => 'colorpicker',
                                'param_name' => 'button_hover_border_color',
                                'heading'    => esc_html__( 'Button Hover Border Color', 'select-core' ),
                                'dependency' => array( 'element' => 'type', 'value' => array( 'normal' ) ),
                                'group'      => esc_html__( 'Button Style', 'select-core' )
                            ),
                            array(
                                'type'       => 'textarea_html',
                                'param_name' => 'content',
                                'heading'    => esc_html__( 'Content', 'select-core' ),
                                'value'      => esc_html__( 'I am test text for Call to Action shortcode content', 'select-core' )
                            )
                        ))
                    )
			);
		}
	}
	
	public function render( $atts, $content = null ) {
		$args   = array(
			'custom_class'                  => '',
			'type'                          => 'normal',
            'custom_icon_size'              => '',
            'link'                          => '',
            'link_skin'                     => '',
			'content_in_grid'               => 'no',
			'content_elements_proportion'   => '75',
			'button_text'                   => '',
			'button_top_margin'             => '',
			'button_type'                   => 'solid',
			'button_size'                   => 'medium',
			'button_link'                   => '',
			'button_target'                 => '_self',
			'button_color'                  => '',
			'button_hover_color'            => '',
			'button_background_color'       => '',
			'button_hover_background_color' => '',
			'button_border_color'           => '',
			'button_hover_border_color'     => ''
		);
        $args = array_merge( $args, aoki_qodef_icon_collections()->getShortcodeParams() );
        $params = shortcode_atts( $args, $atts );
		
		$params['content'] = preg_replace( '#^<\/p>|<p>$#', '', $content );
		
		$params['holder_classes']       = $this->getHolderClasses( $params );
		$params['inner_classes']        = $this->getInnerClasses( $params );
		$params['button_holder_styles'] = $this->getButtonHolderStyles( $params );
		$params['button_parameters']    = $this->getButtonParameters( $params );
        $params['icon_parameters'] = $this->getIconParameters( $params );
		
		$html = qodef_core_get_shortcode_module_template_part( 'templates/call-to-action', 'call-to-action', $params['type'], $params );
		
		return $html;
	}
	
	private function getHolderClasses( $params ) {
		$holderClasses = array();
		
		$holderClasses[] = ! empty( $params['custom_class'] ) ? esc_attr( $params['custom_class'] ) : '';
		$holderClasses[] = ! empty( $params['type'] ) ? 'qodef-' . $params['type'] . '-layout' : '';
		$holderClasses[] = $params['content_in_grid'] === 'yes' && $params['type'] === 'normal' ? 'qodef-content-in-grid' : '';
		$holderClasses[] = $params['link_skin'];

		$content_elements_proportion = $params['content_elements_proportion'];
		if ( $params['type'] === 'normal' ) {
			switch ( $content_elements_proportion ):
				case '80':
					$holderClasses[] = 'qodef-four-fifths-columns';
					break;
				case '75':
					$holderClasses[] = 'qodef-three-quarters-columns';
					break;
				case '66':
					$holderClasses[] = 'qodef-two-thirds-columns';
					break;
				case '50':
					$holderClasses[] = 'qodef-two-halves-columns';
					break;
				default:
					$holderClasses[] = 'qodef-three-quarters-columns';
					break;
			endswitch;
		}
		
		return implode( ' ', $holderClasses );
	}
	
	private function getInnerClasses( $params ) {
		$innerClasses = array();
		
		$innerClasses[] = $params['type'] === 'normal' && $params['content_in_grid'] === 'yes' ? 'qodef-grid' : '';
		
		return implode( ' ', $innerClasses );
	}
	
	private function getButtonHolderStyles( $params ) {
		$styles = array();
		
		if ( ! empty( $params['button_top_margin'] ) && $params['type'] === 'simple' ) {
			$styles[] = 'margin-top: ' . aoki_qodef_filter_px( $params['button_top_margin'] ) . 'px';
		}
		
		return implode( ';', $styles );
	}
	
	private function getButtonParameters( $params ) {
		$button_params_array = array();
		
		if ( ! empty( $params['button_text'] ) ) {
			$button_params_array['text'] = $params['button_text'];
		}
		
		if ( ! empty( $params['button_type'] ) ) {
			$button_params_array['type'] = $params['button_type'];
		}
		
		if ( ! empty( $params['button_size'] ) ) {
			$button_params_array['size'] = $params['button_size'];
		}
		
		if ( ! empty( $params['button_link'] ) ) {
			$button_params_array['link'] = $params['button_link'];
		}
		
		$button_params_array['target'] = ! empty( $params['button_target'] ) ? $params['button_target'] : '_self';
		
		if ( ! empty( $params['button_color'] ) ) {
			$button_params_array['color'] = $params['button_color'];
		}
		
		if ( ! empty( $params['button_hover_color'] ) ) {
			$button_params_array['hover_color'] = $params['button_hover_color'];
		}
		
		if ( ! empty( $params['button_background_color'] ) ) {
			$button_params_array['background_color'] = $params['button_background_color'];
		}
		
		if ( ! empty( $params['button_hover_background_color'] ) ) {
			$button_params_array['hover_background_color'] = $params['button_hover_background_color'];
		}
		
		if ( ! empty( $params['button_border_color'] ) ) {
			$button_params_array['border_color'] = $params['button_border_color'];
		}
		
		if ( ! empty( $params['button_hover_border_color'] ) ) {
			$button_params_array['hover_border_color'] = $params['button_hover_border_color'];
		}
		
		return $button_params_array;
	}

    private function getIconParameters( $params ) {
        $params_array = array();

        $iconPackName = aoki_qodef_icon_collections()->getIconCollectionParamNameByKey( $params['icon_pack'] );

        $params_array['icon_pack']     = $params['icon_pack'];
        $params_array[ $iconPackName ] = $params[ $iconPackName ];

        if ( ! empty( $params['custom_icon_size'] ) ) {
            $params_array['custom_size'] = aoki_qodef_filter_px( $params['custom_icon_size'] ) . 'px';
        }


        return $params_array;
    }
}